/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMapiRegistry.idl
 */

#ifndef __gen_nsIMapiRegistry_h__
#define __gen_nsIMapiRegistry_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMWindow; /* forward declaration */


/* starting interface:    nsIMapiRegistry */
#define NS_IMAPIREGISTRY_IID_STR "b0342ca7-cb85-4d13-ad18-bd431f2086ea"

#define NS_IMAPIREGISTRY_IID \
  {0xb0342ca7, 0xcb85, 0x4d13, \
    { 0xad, 0x18, 0xbd, 0x43, 0x1f, 0x20, 0x86, 0xea }}

/**
 * This interface provides support for registering Mozilla as the default
 * Mail Client. This interface can also be used to get/set the user preference
 * for the default Mail Client.
 * 
 */
class NS_NO_VTABLE nsIMapiRegistry : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMAPIREGISTRY_IID)

  /** This is set to TRUE if Mozilla is the default mail application
    */
  /* attribute boolean isDefaultMailClient; */
  NS_IMETHOD GetIsDefaultMailClient(PRBool *aIsDefaultMailClient) = 0;
  NS_IMETHOD SetIsDefaultMailClient(PRBool aIsDefaultMailClient) = 0;

  /* attribute boolean isDefaultNewsClient; */
  NS_IMETHOD GetIsDefaultNewsClient(PRBool *aIsDefaultNewsClient) = 0;
  NS_IMETHOD SetIsDefaultNewsClient(PRBool aIsDefaultNewsClient) = 0;

  /* attribute boolean isDefaultFeedClient; */
  NS_IMETHOD GetIsDefaultFeedClient(PRBool *aIsDefaultFeedClient) = 0;
  NS_IMETHOD SetIsDefaultFeedClient(PRBool aIsDefaultFeedClient) = 0;

  /** This is set TRUE only once per session.
    */
  /* readonly attribute boolean showDialog; */
  NS_IMETHOD GetShowDialog(PRBool *aShowDialog) = 0;

  /** This will bring the dialog asking the user if he/she wants to set
    * Mozilla as default Mail Client.
    * Call this only if Mozilla is not the default Mail client
    */
  /* void showMailIntegrationDialog (in nsIDOMWindow parentWindow); */
  NS_IMETHOD ShowMailIntegrationDialog(nsIDOMWindow *parentWindow) = 0;

  /* void registerMailAndNewsClient (); */
  NS_IMETHOD RegisterMailAndNewsClient(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMAPIREGISTRY \
  NS_IMETHOD GetIsDefaultMailClient(PRBool *aIsDefaultMailClient); \
  NS_IMETHOD SetIsDefaultMailClient(PRBool aIsDefaultMailClient); \
  NS_IMETHOD GetIsDefaultNewsClient(PRBool *aIsDefaultNewsClient); \
  NS_IMETHOD SetIsDefaultNewsClient(PRBool aIsDefaultNewsClient); \
  NS_IMETHOD GetIsDefaultFeedClient(PRBool *aIsDefaultFeedClient); \
  NS_IMETHOD SetIsDefaultFeedClient(PRBool aIsDefaultFeedClient); \
  NS_IMETHOD GetShowDialog(PRBool *aShowDialog); \
  NS_IMETHOD ShowMailIntegrationDialog(nsIDOMWindow *parentWindow); \
  NS_IMETHOD RegisterMailAndNewsClient(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMAPIREGISTRY(_to) \
  NS_IMETHOD GetIsDefaultMailClient(PRBool *aIsDefaultMailClient) { return _to GetIsDefaultMailClient(aIsDefaultMailClient); } \
  NS_IMETHOD SetIsDefaultMailClient(PRBool aIsDefaultMailClient) { return _to SetIsDefaultMailClient(aIsDefaultMailClient); } \
  NS_IMETHOD GetIsDefaultNewsClient(PRBool *aIsDefaultNewsClient) { return _to GetIsDefaultNewsClient(aIsDefaultNewsClient); } \
  NS_IMETHOD SetIsDefaultNewsClient(PRBool aIsDefaultNewsClient) { return _to SetIsDefaultNewsClient(aIsDefaultNewsClient); } \
  NS_IMETHOD GetIsDefaultFeedClient(PRBool *aIsDefaultFeedClient) { return _to GetIsDefaultFeedClient(aIsDefaultFeedClient); } \
  NS_IMETHOD SetIsDefaultFeedClient(PRBool aIsDefaultFeedClient) { return _to SetIsDefaultFeedClient(aIsDefaultFeedClient); } \
  NS_IMETHOD GetShowDialog(PRBool *aShowDialog) { return _to GetShowDialog(aShowDialog); } \
  NS_IMETHOD ShowMailIntegrationDialog(nsIDOMWindow *parentWindow) { return _to ShowMailIntegrationDialog(parentWindow); } \
  NS_IMETHOD RegisterMailAndNewsClient(void) { return _to RegisterMailAndNewsClient(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMAPIREGISTRY(_to) \
  NS_IMETHOD GetIsDefaultMailClient(PRBool *aIsDefaultMailClient) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsDefaultMailClient(aIsDefaultMailClient); } \
  NS_IMETHOD SetIsDefaultMailClient(PRBool aIsDefaultMailClient) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIsDefaultMailClient(aIsDefaultMailClient); } \
  NS_IMETHOD GetIsDefaultNewsClient(PRBool *aIsDefaultNewsClient) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsDefaultNewsClient(aIsDefaultNewsClient); } \
  NS_IMETHOD SetIsDefaultNewsClient(PRBool aIsDefaultNewsClient) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIsDefaultNewsClient(aIsDefaultNewsClient); } \
  NS_IMETHOD GetIsDefaultFeedClient(PRBool *aIsDefaultFeedClient) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsDefaultFeedClient(aIsDefaultFeedClient); } \
  NS_IMETHOD SetIsDefaultFeedClient(PRBool aIsDefaultFeedClient) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIsDefaultFeedClient(aIsDefaultFeedClient); } \
  NS_IMETHOD GetShowDialog(PRBool *aShowDialog) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetShowDialog(aShowDialog); } \
  NS_IMETHOD ShowMailIntegrationDialog(nsIDOMWindow *parentWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->ShowMailIntegrationDialog(parentWindow); } \
  NS_IMETHOD RegisterMailAndNewsClient(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->RegisterMailAndNewsClient(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMapiRegistry : public nsIMapiRegistry
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMAPIREGISTRY

  nsMapiRegistry();

private:
  ~nsMapiRegistry();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMapiRegistry, nsIMapiRegistry)

nsMapiRegistry::nsMapiRegistry()
{
  /* member initializers and constructor code */
}

nsMapiRegistry::~nsMapiRegistry()
{
  /* destructor code */
}

/* attribute boolean isDefaultMailClient; */
NS_IMETHODIMP nsMapiRegistry::GetIsDefaultMailClient(PRBool *aIsDefaultMailClient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMapiRegistry::SetIsDefaultMailClient(PRBool aIsDefaultMailClient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean isDefaultNewsClient; */
NS_IMETHODIMP nsMapiRegistry::GetIsDefaultNewsClient(PRBool *aIsDefaultNewsClient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMapiRegistry::SetIsDefaultNewsClient(PRBool aIsDefaultNewsClient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean isDefaultFeedClient; */
NS_IMETHODIMP nsMapiRegistry::GetIsDefaultFeedClient(PRBool *aIsDefaultFeedClient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMapiRegistry::SetIsDefaultFeedClient(PRBool aIsDefaultFeedClient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean showDialog; */
NS_IMETHODIMP nsMapiRegistry::GetShowDialog(PRBool *aShowDialog)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void showMailIntegrationDialog (in nsIDOMWindow parentWindow); */
NS_IMETHODIMP nsMapiRegistry::ShowMailIntegrationDialog(nsIDOMWindow *parentWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void registerMailAndNewsClient (); */
NS_IMETHODIMP nsMapiRegistry::RegisterMailAndNewsClient()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

#define NS_IMAPIREGISTRY_CONTRACTID    "@mozilla.org/mapiregistry;1"
#define NS_IMAPIREGISTRY_CLASSNAME "Mozilla MAPI Registry"

#endif /* __gen_nsIMapiRegistry_h__ */
