/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgMailSession.idl
 */

#ifndef __gen_nsIMsgMailSession_h__
#define __gen_nsIMsgMailSession_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIFolderListener_h__
#include "nsIFolderListener.h"
#endif

#ifndef __gen_nsIMsgWindow_h__
#include "nsIMsgWindow.h"
#endif

#ifndef __gen_nsISupportsArray_h__
#include "nsISupportsArray.h"
#endif

#ifndef __gen_nsIAtom_h__
#include "nsIAtom.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgWindow; /* forward declaration */

class nsIFile; /* forward declaration */


/* starting interface:    nsIMsgMailSession */
#define NS_IMSGMAILSESSION_IID_STR "d5124440-d59e-11d2-806a-006008128c4e"

#define NS_IMSGMAILSESSION_IID \
  {0xd5124440, 0xd59e, 0x11d2, \
    { 0x80, 0x6a, 0x00, 0x60, 0x08, 0x12, 0x8c, 0x4e }}

class NS_NO_VTABLE nsIMsgMailSession : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGMAILSESSION_IID)

  /* void Shutdown (); */
  NS_IMETHOD Shutdown(void) = 0;

  /* void AddFolderListener (in nsIFolderListener listener, in folderListenerNotifyFlagValue notifyFlags); */
  NS_IMETHOD AddFolderListener(nsIFolderListener *listener, folderListenerNotifyFlagValue notifyFlags) = 0;

  /* void RemoveFolderListener (in nsIFolderListener listener); */
  NS_IMETHOD RemoveFolderListener(nsIFolderListener *listener) = 0;

  /* readonly attribute nsIMsgWindow topmostMsgWindow; */
  NS_IMETHOD GetTopmostMsgWindow(nsIMsgWindow * *aTopmostMsgWindow) = 0;

  /* void AddMsgWindow (in nsIMsgWindow msgWindow); */
  NS_IMETHOD AddMsgWindow(nsIMsgWindow *msgWindow) = 0;

  /* void RemoveMsgWindow (in nsIMsgWindow msgWindow); */
  NS_IMETHOD RemoveMsgWindow(nsIMsgWindow *msgWindow) = 0;

  /* readonly attribute nsISupportsArray msgWindowsArray; */
  NS_IMETHOD GetMsgWindowsArray(nsISupportsArray * *aMsgWindowsArray) = 0;

  /* boolean IsFolderOpenInWindow (in nsIMsgFolder folder); */
  NS_IMETHOD IsFolderOpenInWindow(nsIMsgFolder *folder, PRBool *_retval) = 0;

  /* string ConvertMsgURIToMsgURL (in string aURI, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD ConvertMsgURIToMsgURL(const char *aURI, nsIMsgWindow *aMsgWindow, char **_retval) = 0;

  /* nsIFile getDataFilesDir (in string dirName); */
  NS_IMETHOD GetDataFilesDir(const char *dirName, nsIFile **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGMAILSESSION \
  NS_IMETHOD Shutdown(void); \
  NS_IMETHOD AddFolderListener(nsIFolderListener *listener, folderListenerNotifyFlagValue notifyFlags); \
  NS_IMETHOD RemoveFolderListener(nsIFolderListener *listener); \
  NS_IMETHOD GetTopmostMsgWindow(nsIMsgWindow * *aTopmostMsgWindow); \
  NS_IMETHOD AddMsgWindow(nsIMsgWindow *msgWindow); \
  NS_IMETHOD RemoveMsgWindow(nsIMsgWindow *msgWindow); \
  NS_IMETHOD GetMsgWindowsArray(nsISupportsArray * *aMsgWindowsArray); \
  NS_IMETHOD IsFolderOpenInWindow(nsIMsgFolder *folder, PRBool *_retval); \
  NS_IMETHOD ConvertMsgURIToMsgURL(const char *aURI, nsIMsgWindow *aMsgWindow, char **_retval); \
  NS_IMETHOD GetDataFilesDir(const char *dirName, nsIFile **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGMAILSESSION(_to) \
  NS_IMETHOD Shutdown(void) { return _to Shutdown(); } \
  NS_IMETHOD AddFolderListener(nsIFolderListener *listener, folderListenerNotifyFlagValue notifyFlags) { return _to AddFolderListener(listener, notifyFlags); } \
  NS_IMETHOD RemoveFolderListener(nsIFolderListener *listener) { return _to RemoveFolderListener(listener); } \
  NS_IMETHOD GetTopmostMsgWindow(nsIMsgWindow * *aTopmostMsgWindow) { return _to GetTopmostMsgWindow(aTopmostMsgWindow); } \
  NS_IMETHOD AddMsgWindow(nsIMsgWindow *msgWindow) { return _to AddMsgWindow(msgWindow); } \
  NS_IMETHOD RemoveMsgWindow(nsIMsgWindow *msgWindow) { return _to RemoveMsgWindow(msgWindow); } \
  NS_IMETHOD GetMsgWindowsArray(nsISupportsArray * *aMsgWindowsArray) { return _to GetMsgWindowsArray(aMsgWindowsArray); } \
  NS_IMETHOD IsFolderOpenInWindow(nsIMsgFolder *folder, PRBool *_retval) { return _to IsFolderOpenInWindow(folder, _retval); } \
  NS_IMETHOD ConvertMsgURIToMsgURL(const char *aURI, nsIMsgWindow *aMsgWindow, char **_retval) { return _to ConvertMsgURIToMsgURL(aURI, aMsgWindow, _retval); } \
  NS_IMETHOD GetDataFilesDir(const char *dirName, nsIFile **_retval) { return _to GetDataFilesDir(dirName, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGMAILSESSION(_to) \
  NS_IMETHOD Shutdown(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Shutdown(); } \
  NS_IMETHOD AddFolderListener(nsIFolderListener *listener, folderListenerNotifyFlagValue notifyFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddFolderListener(listener, notifyFlags); } \
  NS_IMETHOD RemoveFolderListener(nsIFolderListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveFolderListener(listener); } \
  NS_IMETHOD GetTopmostMsgWindow(nsIMsgWindow * *aTopmostMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTopmostMsgWindow(aTopmostMsgWindow); } \
  NS_IMETHOD AddMsgWindow(nsIMsgWindow *msgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddMsgWindow(msgWindow); } \
  NS_IMETHOD RemoveMsgWindow(nsIMsgWindow *msgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveMsgWindow(msgWindow); } \
  NS_IMETHOD GetMsgWindowsArray(nsISupportsArray * *aMsgWindowsArray) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgWindowsArray(aMsgWindowsArray); } \
  NS_IMETHOD IsFolderOpenInWindow(nsIMsgFolder *folder, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsFolderOpenInWindow(folder, _retval); } \
  NS_IMETHOD ConvertMsgURIToMsgURL(const char *aURI, nsIMsgWindow *aMsgWindow, char **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ConvertMsgURIToMsgURL(aURI, aMsgWindow, _retval); } \
  NS_IMETHOD GetDataFilesDir(const char *dirName, nsIFile **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDataFilesDir(dirName, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgMailSession : public nsIMsgMailSession
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGMAILSESSION

  nsMsgMailSession();

private:
  ~nsMsgMailSession();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgMailSession, nsIMsgMailSession)

nsMsgMailSession::nsMsgMailSession()
{
  /* member initializers and constructor code */
}

nsMsgMailSession::~nsMsgMailSession()
{
  /* destructor code */
}

/* void Shutdown (); */
NS_IMETHODIMP nsMsgMailSession::Shutdown()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void AddFolderListener (in nsIFolderListener listener, in folderListenerNotifyFlagValue notifyFlags); */
NS_IMETHODIMP nsMsgMailSession::AddFolderListener(nsIFolderListener *listener, folderListenerNotifyFlagValue notifyFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void RemoveFolderListener (in nsIFolderListener listener); */
NS_IMETHODIMP nsMsgMailSession::RemoveFolderListener(nsIFolderListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMsgWindow topmostMsgWindow; */
NS_IMETHODIMP nsMsgMailSession::GetTopmostMsgWindow(nsIMsgWindow * *aTopmostMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void AddMsgWindow (in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsMsgMailSession::AddMsgWindow(nsIMsgWindow *msgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void RemoveMsgWindow (in nsIMsgWindow msgWindow); */
NS_IMETHODIMP nsMsgMailSession::RemoveMsgWindow(nsIMsgWindow *msgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsISupportsArray msgWindowsArray; */
NS_IMETHODIMP nsMsgMailSession::GetMsgWindowsArray(nsISupportsArray * *aMsgWindowsArray)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean IsFolderOpenInWindow (in nsIMsgFolder folder); */
NS_IMETHODIMP nsMsgMailSession::IsFolderOpenInWindow(nsIMsgFolder *folder, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string ConvertMsgURIToMsgURL (in string aURI, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgMailSession::ConvertMsgURIToMsgURL(const char *aURI, nsIMsgWindow *aMsgWindow, char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIFile getDataFilesDir (in string dirName); */
NS_IMETHODIMP nsMsgMailSession::GetDataFilesDir(const char *dirName, nsIFile **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgMailSession_h__ */
