/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIUrlClassifierTable.idl
 */

#ifndef __gen_nsIUrlClassifierTable_h__
#define __gen_nsIUrlClassifierTable_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIUrlListManager_h__
#include "nsIUrlListManager.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIUrlClassifierTable */
#define NS_IURLCLASSIFIERTABLE_IID_STR "fd1f8334-1859-472d-b01f-4ac6b1121ce4"

#define NS_IURLCLASSIFIERTABLE_IID \
  {0xfd1f8334, 0x1859, 0x472d, \
    { 0xb0, 0x1f, 0x4a, 0xc6, 0xb1, 0x12, 0x1c, 0xe4 }}

class NS_NO_VTABLE nsIUrlClassifierTable : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IURLCLASSIFIERTABLE_IID)

  /**
     * The name used to identify this table
     */
  /* attribute ACString name; */
  NS_IMETHOD GetName(nsACString & aName) = 0;
  NS_IMETHOD SetName(const nsACString & aName) = 0;

  /**
     * Set to false if we don't want to update this table.
     */
  /* attribute boolean needsUpdate; */
  NS_IMETHOD GetNeedsUpdate(PRBool *aNeedsUpdate) = 0;
  NS_IMETHOD SetNeedsUpdate(PRBool aNeedsUpdate) = 0;

  /**
     * In the simple case, exists just looks up the string in the
     * table and call the callback after the query returns with true or
     * false.  It's possible that something more complex happens
     * (e.g., canonicalize the url).
     */
  /* void exists (in ACString key, in nsIUrlListManagerCallback cb); */
  NS_IMETHOD Exists(const nsACString & key, nsIUrlListManagerCallback *cb) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIURLCLASSIFIERTABLE \
  NS_IMETHOD GetName(nsACString & aName); \
  NS_IMETHOD SetName(const nsACString & aName); \
  NS_IMETHOD GetNeedsUpdate(PRBool *aNeedsUpdate); \
  NS_IMETHOD SetNeedsUpdate(PRBool aNeedsUpdate); \
  NS_IMETHOD Exists(const nsACString & key, nsIUrlListManagerCallback *cb); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIURLCLASSIFIERTABLE(_to) \
  NS_IMETHOD GetName(nsACString & aName) { return _to GetName(aName); } \
  NS_IMETHOD SetName(const nsACString & aName) { return _to SetName(aName); } \
  NS_IMETHOD GetNeedsUpdate(PRBool *aNeedsUpdate) { return _to GetNeedsUpdate(aNeedsUpdate); } \
  NS_IMETHOD SetNeedsUpdate(PRBool aNeedsUpdate) { return _to SetNeedsUpdate(aNeedsUpdate); } \
  NS_IMETHOD Exists(const nsACString & key, nsIUrlListManagerCallback *cb) { return _to Exists(key, cb); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIURLCLASSIFIERTABLE(_to) \
  NS_IMETHOD GetName(nsACString & aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetName(aName); } \
  NS_IMETHOD SetName(const nsACString & aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetName(aName); } \
  NS_IMETHOD GetNeedsUpdate(PRBool *aNeedsUpdate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNeedsUpdate(aNeedsUpdate); } \
  NS_IMETHOD SetNeedsUpdate(PRBool aNeedsUpdate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetNeedsUpdate(aNeedsUpdate); } \
  NS_IMETHOD Exists(const nsACString & key, nsIUrlListManagerCallback *cb) { return !_to ? NS_ERROR_NULL_POINTER : _to->Exists(key, cb); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsUrlClassifierTable : public nsIUrlClassifierTable
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIURLCLASSIFIERTABLE

  nsUrlClassifierTable();

private:
  ~nsUrlClassifierTable();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsUrlClassifierTable, nsIUrlClassifierTable)

nsUrlClassifierTable::nsUrlClassifierTable()
{
  /* member initializers and constructor code */
}

nsUrlClassifierTable::~nsUrlClassifierTable()
{
  /* destructor code */
}

/* attribute ACString name; */
NS_IMETHODIMP nsUrlClassifierTable::GetName(nsACString & aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsUrlClassifierTable::SetName(const nsACString & aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean needsUpdate; */
NS_IMETHODIMP nsUrlClassifierTable::GetNeedsUpdate(PRBool *aNeedsUpdate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsUrlClassifierTable::SetNeedsUpdate(PRBool aNeedsUpdate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void exists (in ACString key, in nsIUrlListManagerCallback cb); */
NS_IMETHODIMP nsUrlClassifierTable::Exists(const nsACString & key, nsIUrlListManagerCallback *cb)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIUrlClassifierTable_h__ */
