/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Frank Yung-Fong Tang <ftang@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
interface nsIFontPackageHandler;

%{C++
// {6712FDD6-F978-11d4-A144-005004832142}
#define NS_FONTPACKAGESERVICE_CID \
{ 0x6712fdd6, 0xf978, 0x11d4, { 0xa1, 0x44, 0x0, 0x50, 0x4, 0x83, 0x21, 0x42 } }
#define NS_FONTPACKAGESERVICE_CONTRACTID \
  "@mozilla.org/intl/fontpackageservice;1"

%}

[scriptable, uuid(6712FDD2-F978-11d4-A144-005004832142)]
interface nsIFontPackageService : nsISupports {
   /*
    * Set a handler to handle missing font package
    *
    * @param aHandler a nsIFontPackageHandler
    */
   void SetHandler( in nsIFontPackageHandler aHandler);

   /*
    * Notify the installation have been handled
    * @param aSuccess to notify it is a success installation or not
    * @param aRedrawPages to notify to reload all relate page or not
    * @param aFontPackID a font package id, this should be the same value pass to
    *        nsIFontPackageHandler::
    * The id have the following naming convenation 
    *   name_space:name
    * we currently define one name space
    *    lang - a font package for a particular language group
    * and udnder the lang name space, we use the language code to identify
    * the package, below are the defined packages
    *    ja - Japanese font package ("lang:ja")
    *    ko - Korean font package ("lang:ko")
    *    zh-TW - Traditional Chinese font package ("lang:zh-TW")
    *    zh-CN - Simplified Chinese font package ("lang:zh-CN")
    * In the future, we may want to add
    *    ar - Arabic font packges ("lang:ar")
    *    he - Hebrew font packages ("lang:he")
    *    th - Thai font package ("lang:th")
    * other name space are reserved for now.
    */
   void FontPackageHandled(in boolean aSuccess, in boolean aRedrawPages, in string aFontPackID );
};

