/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/* The nsIMsgStringService is a a generic interface for our
   component based string bundle services. The idea is to have
   say imap implement this interface for the imap string bundle. 
   local will have its own version of the service for local 
   strings (pop, mailbox). 

   The first time the service is asked to fetch the string for an ID, 
   it will cache the string bundle that is returned and re-use it for 
   all future requests.
*/
#include "nsISupports.idl"

#include "nsIStringBundle.idl"

[scriptable, uuid(6AC107B1-D558-11d3-98B1-001083010E9B)]
interface nsIMsgStringService : nsISupports {
  /* GetStringByID --> pass in the ID for the string you are
     interested in. You get back a PRUnichar * which you must
     of course release
  */
  wstring getStringByID (in long aStringID);
  readonly attribute nsIStringBundle bundle;
};

%{C++
#define NS_MAILNEWS_STRINGSERVICE_CONTRACTID      "@mozilla.org/messenger/stringservice;1"
#define NS_MAILNEWS_STRINGSERVICE_CONTRACTID_PREFIX NS_MAILNEWS_STRINGSERVICE_CONTRACTID"?type="
%}
