/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsINoneService.idl
 */

#ifndef __gen_nsINoneService_h__
#define __gen_nsINoneService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsINoneService */
#define NS_INONESERVICE_IID_STR "14714890-1dd2-11b2-87de-d265839520d6"

#define NS_INONESERVICE_IID \
  {0x14714890, 0x1dd2, 0x11b2, \
    { 0x87, 0xde, 0xd2, 0x65, 0x83, 0x95, 0x20, 0xd6 }}

class NS_NO_VTABLE nsINoneService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_INONESERVICE_IID)

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSINONESERVICE \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSINONESERVICE(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSINONESERVICE(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsNoneService : public nsINoneService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSINONESERVICE

  nsNoneService();

private:
  ~nsNoneService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsNoneService, nsINoneService)

nsNoneService::nsNoneService()
{
  /* member initializers and constructor code */
}

nsNoneService::~nsNoneService()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsINoneService_h__ */
