/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsIMsgRecipientArray.idl"
#include "nsIMsgAttachment.idl"
#include "nsISupportsArray.idl"

[scriptable, uuid(f5a85828-e9ef-4821-a045-6dc7a09351d6)]
interface nsIMsgCompFields : nsISupports {

  attribute AString from;
  attribute AString replyTo;
  attribute AString to;
  attribute AString cc;
  attribute AString bcc;
  
  attribute AString fcc;
  attribute AString fcc2;
  
  attribute AString newsgroups;
  attribute string  newshost;
  attribute string  newspostUrl;
  attribute string  followupTo;

  attribute AString subject;
  
  /**
   * attachments
   *
   * @OBSOLETE, DO NOT USE ANYMORE
   */
  attribute string  attachments;

  attribute AString organization;
  attribute string  references;
  attribute string  priority;
  attribute string  messageId;
  attribute string  characterSet;
  readonly attribute string defaultCharacterSet;

  attribute AString templateName;
  attribute string  draftId;

  attribute boolean returnReceipt;
  attribute long receiptHeaderType;
  attribute boolean attachVCard;
  attribute boolean forcePlainText;
  attribute boolean useMultipartAlternative;
  attribute boolean uuEncodeAttachments;
  attribute boolean bodyIsAsciiOnly;
  attribute boolean forceMsgEncoding;

  attribute AString otherRandomHeaders;

  attribute AString body;

  /**
   * temporaryFiles
   *
   * @OBSOLETE, DO NOT USE ANYMORE
   */
  attribute string  temporaryFiles;
  
  readonly attribute nsISupportsArray attachmentsArray;
  void addAttachment(in nsIMsgAttachment attachment);
  void removeAttachment(in nsIMsgAttachment attachment);
  void removeAttachments();

  /* some utility functions */
  nsIMsgRecipientArray SplitRecipients(in wstring recipients, in boolean emailAddressOnly);    
  void ConvertBodyToPlainText();

  // Check if the composing mail headers can be converted to a mail charset.
  boolean checkCharsetConversion(out string fallbackCharset);

  /** 
   * Indicates whether we need to check if the current |DocumentCharset|
   * can represent all the characters in the message body. It should be
   * initialized to true and set to false when 'Send Anyway' is selected
   * by a user. (bug 249530)
   */
  attribute boolean needToCheckCharset; 

  attribute nsISupports securityInfo;
};

