/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
#include "nsISupports.idl"
#include "nsrootidl.idl"

interface nsIOutputStream;
interface nsIInputStream;
interface nsIURI;
interface nsIStreamListener;
interface nsIChannel;

[scriptable, uuid(39E329E2-357F-11d3-8EFD-00A024A7D144)] 
interface nsMimeHeaderDisplayTypes 
{ 
    const long MicroHeaders = 0; 
    const long NormalHeaders = 1; 
    const long AllHeaders = 2; 
}; 

%{C++
//#define NS_IMIME_MISC_STATUS_KEY       "@mozilla.org/messenger/mimestatus;1?"
#define NS_IMIME_MISC_STATUS_KEY       "@mozilla.org/MimeMiscStatus;1?type="
%}

[scriptable, uuid(D01D7B59-DCCD-11d2-A411-00805F613C79)]
interface nsIMimeEmitter : nsISupports{

    // These will be called to start and stop the total operation
    void    Initialize(in nsIURI url, in nsIChannel aChannel, in long aFormat);
    void    Complete();

    // Set the output stream/listener for processed data.
    void    SetPipe(in nsIInputStream inputStream, in nsIOutputStream outStream);
    void    SetOutputListener(in nsIStreamListener listener);
    
    //Get the output listener to allow access to it from mime
    nsIStreamListener    GetOutputListener();

    // Header handling routines.
    void    StartHeader(in PRBool rootMailHeader, in PRBool headerOnly, 
                        [const] in string msgID, [const] in string outCharset);
    void    AddHeaderField([const] in string field, [const] in string value);
    void    addAllHeaders([const] in string allheaders, [const] in long allheadersize);
	void    WriteHTMLHeaders(); // book case this with a EndHeader call.
    void    EndHeader();
    void    UpdateCharacterSet([const] in string aCharset);

    // Attachment handling routines
    void    StartAttachment([const] in string name, [const] in string contentType, 
                            [const] in string url, in PRBool aNotDownloaded);
    void    AddAttachmentField([const] in string field, [const] in string value);
    void    EndAttachment();

    void    EndAllAttachments();

    // Body handling routines
    void    StartBody(in PRBool bodyOnly, [const] in string msgID, [const] in string outCharset);
    void    WriteBody([const] in string buf, in PRUint32 size, out PRUint32 amountWritten);
    void    EndBody();

    // Generic write routine. This is necessary for output that
    // libmime needs to pass through without any particular parsing
    // involved (i.e. decoded images, HTML Body Text, etc...
    void    Write([const] in string buf, in PRUint32 size, out PRUint32 amountWritten);
    void    UtilityWrite([const] in string buf);
};

