/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM inIFileSearch.idl
 */

#ifndef __gen_inIFileSearch_h__
#define __gen_inIFileSearch_h__


#ifndef __gen_inISearchProcess_h__
#include "inISearchProcess.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */

class nsISupportsArray; /* forward declaration */


/* starting interface:    inIFileSearch */
#define INIFILESEARCH_IID_STR "efa53257-526d-4350-9088-343a510346b8"

#define INIFILESEARCH_IID \
  {0xefa53257, 0x526d, 0x4350, \
    { 0x90, 0x88, 0x34, 0x3a, 0x51, 0x03, 0x46, 0xb8 }}

class NS_NO_VTABLE inIFileSearch : public inISearchProcess {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(INIFILESEARCH_IID)

  /* attribute wstring basePath; */
  NS_IMETHOD GetBasePath(PRUnichar * *aBasePath) = 0;
  NS_IMETHOD SetBasePath(const PRUnichar * aBasePath) = 0;

  /* attribute boolean returnRelativePaths; */
  NS_IMETHOD GetReturnRelativePaths(PRBool *aReturnRelativePaths) = 0;
  NS_IMETHOD SetReturnRelativePaths(PRBool aReturnRelativePaths) = 0;

  /* unsigned long getDirectoryDepth (in nsIFile aDir); */
  NS_IMETHOD GetDirectoryDepth(nsIFile *aDir, PRUint32 *_retval) = 0;

  /* nsISupportsArray getSubDirectories (in nsIFile aDir); */
  NS_IMETHOD GetSubDirectories(nsIFile *aDir, nsISupportsArray **_retval) = 0;

  /* attribute wstring filenameCriteria; */
  NS_IMETHOD GetFilenameCriteria(PRUnichar * *aFilenameCriteria) = 0;
  NS_IMETHOD SetFilenameCriteria(const PRUnichar * aFilenameCriteria) = 0;

  /* attribute wstring textCriteria; */
  NS_IMETHOD GetTextCriteria(PRUnichar * *aTextCriteria) = 0;
  NS_IMETHOD SetTextCriteria(const PRUnichar * aTextCriteria) = 0;

  /* attribute nsIFile searchPath; */
  NS_IMETHOD GetSearchPath(nsIFile * *aSearchPath) = 0;
  NS_IMETHOD SetSearchPath(nsIFile * aSearchPath) = 0;

  /* attribute boolean searchRecursive; */
  NS_IMETHOD GetSearchRecursive(PRBool *aSearchRecursive) = 0;
  NS_IMETHOD SetSearchRecursive(PRBool aSearchRecursive) = 0;

  /* readonly attribute unsigned long directoriesSearched; */
  NS_IMETHOD GetDirectoriesSearched(PRUint32 *aDirectoriesSearched) = 0;

  /* readonly attribute nsIFile currentDirectory; */
  NS_IMETHOD GetCurrentDirectory(nsIFile * *aCurrentDirectory) = 0;

  /* nsIFile getFileResultAt (in long aIndex); */
  NS_IMETHOD GetFileResultAt(PRInt32 aIndex, nsIFile **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_INIFILESEARCH \
  NS_IMETHOD GetBasePath(PRUnichar * *aBasePath); \
  NS_IMETHOD SetBasePath(const PRUnichar * aBasePath); \
  NS_IMETHOD GetReturnRelativePaths(PRBool *aReturnRelativePaths); \
  NS_IMETHOD SetReturnRelativePaths(PRBool aReturnRelativePaths); \
  NS_IMETHOD GetDirectoryDepth(nsIFile *aDir, PRUint32 *_retval); \
  NS_IMETHOD GetSubDirectories(nsIFile *aDir, nsISupportsArray **_retval); \
  NS_IMETHOD GetFilenameCriteria(PRUnichar * *aFilenameCriteria); \
  NS_IMETHOD SetFilenameCriteria(const PRUnichar * aFilenameCriteria); \
  NS_IMETHOD GetTextCriteria(PRUnichar * *aTextCriteria); \
  NS_IMETHOD SetTextCriteria(const PRUnichar * aTextCriteria); \
  NS_IMETHOD GetSearchPath(nsIFile * *aSearchPath); \
  NS_IMETHOD SetSearchPath(nsIFile * aSearchPath); \
  NS_IMETHOD GetSearchRecursive(PRBool *aSearchRecursive); \
  NS_IMETHOD SetSearchRecursive(PRBool aSearchRecursive); \
  NS_IMETHOD GetDirectoriesSearched(PRUint32 *aDirectoriesSearched); \
  NS_IMETHOD GetCurrentDirectory(nsIFile * *aCurrentDirectory); \
  NS_IMETHOD GetFileResultAt(PRInt32 aIndex, nsIFile **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_INIFILESEARCH(_to) \
  NS_IMETHOD GetBasePath(PRUnichar * *aBasePath) { return _to GetBasePath(aBasePath); } \
  NS_IMETHOD SetBasePath(const PRUnichar * aBasePath) { return _to SetBasePath(aBasePath); } \
  NS_IMETHOD GetReturnRelativePaths(PRBool *aReturnRelativePaths) { return _to GetReturnRelativePaths(aReturnRelativePaths); } \
  NS_IMETHOD SetReturnRelativePaths(PRBool aReturnRelativePaths) { return _to SetReturnRelativePaths(aReturnRelativePaths); } \
  NS_IMETHOD GetDirectoryDepth(nsIFile *aDir, PRUint32 *_retval) { return _to GetDirectoryDepth(aDir, _retval); } \
  NS_IMETHOD GetSubDirectories(nsIFile *aDir, nsISupportsArray **_retval) { return _to GetSubDirectories(aDir, _retval); } \
  NS_IMETHOD GetFilenameCriteria(PRUnichar * *aFilenameCriteria) { return _to GetFilenameCriteria(aFilenameCriteria); } \
  NS_IMETHOD SetFilenameCriteria(const PRUnichar * aFilenameCriteria) { return _to SetFilenameCriteria(aFilenameCriteria); } \
  NS_IMETHOD GetTextCriteria(PRUnichar * *aTextCriteria) { return _to GetTextCriteria(aTextCriteria); } \
  NS_IMETHOD SetTextCriteria(const PRUnichar * aTextCriteria) { return _to SetTextCriteria(aTextCriteria); } \
  NS_IMETHOD GetSearchPath(nsIFile * *aSearchPath) { return _to GetSearchPath(aSearchPath); } \
  NS_IMETHOD SetSearchPath(nsIFile * aSearchPath) { return _to SetSearchPath(aSearchPath); } \
  NS_IMETHOD GetSearchRecursive(PRBool *aSearchRecursive) { return _to GetSearchRecursive(aSearchRecursive); } \
  NS_IMETHOD SetSearchRecursive(PRBool aSearchRecursive) { return _to SetSearchRecursive(aSearchRecursive); } \
  NS_IMETHOD GetDirectoriesSearched(PRUint32 *aDirectoriesSearched) { return _to GetDirectoriesSearched(aDirectoriesSearched); } \
  NS_IMETHOD GetCurrentDirectory(nsIFile * *aCurrentDirectory) { return _to GetCurrentDirectory(aCurrentDirectory); } \
  NS_IMETHOD GetFileResultAt(PRInt32 aIndex, nsIFile **_retval) { return _to GetFileResultAt(aIndex, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_INIFILESEARCH(_to) \
  NS_IMETHOD GetBasePath(PRUnichar * *aBasePath) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBasePath(aBasePath); } \
  NS_IMETHOD SetBasePath(const PRUnichar * aBasePath) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBasePath(aBasePath); } \
  NS_IMETHOD GetReturnRelativePaths(PRBool *aReturnRelativePaths) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetReturnRelativePaths(aReturnRelativePaths); } \
  NS_IMETHOD SetReturnRelativePaths(PRBool aReturnRelativePaths) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetReturnRelativePaths(aReturnRelativePaths); } \
  NS_IMETHOD GetDirectoryDepth(nsIFile *aDir, PRUint32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDirectoryDepth(aDir, _retval); } \
  NS_IMETHOD GetSubDirectories(nsIFile *aDir, nsISupportsArray **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSubDirectories(aDir, _retval); } \
  NS_IMETHOD GetFilenameCriteria(PRUnichar * *aFilenameCriteria) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFilenameCriteria(aFilenameCriteria); } \
  NS_IMETHOD SetFilenameCriteria(const PRUnichar * aFilenameCriteria) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFilenameCriteria(aFilenameCriteria); } \
  NS_IMETHOD GetTextCriteria(PRUnichar * *aTextCriteria) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTextCriteria(aTextCriteria); } \
  NS_IMETHOD SetTextCriteria(const PRUnichar * aTextCriteria) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetTextCriteria(aTextCriteria); } \
  NS_IMETHOD GetSearchPath(nsIFile * *aSearchPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSearchPath(aSearchPath); } \
  NS_IMETHOD SetSearchPath(nsIFile * aSearchPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSearchPath(aSearchPath); } \
  NS_IMETHOD GetSearchRecursive(PRBool *aSearchRecursive) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSearchRecursive(aSearchRecursive); } \
  NS_IMETHOD SetSearchRecursive(PRBool aSearchRecursive) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSearchRecursive(aSearchRecursive); } \
  NS_IMETHOD GetDirectoriesSearched(PRUint32 *aDirectoriesSearched) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDirectoriesSearched(aDirectoriesSearched); } \
  NS_IMETHOD GetCurrentDirectory(nsIFile * *aCurrentDirectory) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCurrentDirectory(aCurrentDirectory); } \
  NS_IMETHOD GetFileResultAt(PRInt32 aIndex, nsIFile **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFileResultAt(aIndex, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class inFileSearch : public inIFileSearch
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_INIFILESEARCH

  inFileSearch();

private:
  ~inFileSearch();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(inFileSearch, inIFileSearch)

inFileSearch::inFileSearch()
{
  /* member initializers and constructor code */
}

inFileSearch::~inFileSearch()
{
  /* destructor code */
}

/* attribute wstring basePath; */
NS_IMETHODIMP inFileSearch::GetBasePath(PRUnichar * *aBasePath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP inFileSearch::SetBasePath(const PRUnichar * aBasePath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean returnRelativePaths; */
NS_IMETHODIMP inFileSearch::GetReturnRelativePaths(PRBool *aReturnRelativePaths)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP inFileSearch::SetReturnRelativePaths(PRBool aReturnRelativePaths)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* unsigned long getDirectoryDepth (in nsIFile aDir); */
NS_IMETHODIMP inFileSearch::GetDirectoryDepth(nsIFile *aDir, PRUint32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISupportsArray getSubDirectories (in nsIFile aDir); */
NS_IMETHODIMP inFileSearch::GetSubDirectories(nsIFile *aDir, nsISupportsArray **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute wstring filenameCriteria; */
NS_IMETHODIMP inFileSearch::GetFilenameCriteria(PRUnichar * *aFilenameCriteria)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP inFileSearch::SetFilenameCriteria(const PRUnichar * aFilenameCriteria)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute wstring textCriteria; */
NS_IMETHODIMP inFileSearch::GetTextCriteria(PRUnichar * *aTextCriteria)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP inFileSearch::SetTextCriteria(const PRUnichar * aTextCriteria)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIFile searchPath; */
NS_IMETHODIMP inFileSearch::GetSearchPath(nsIFile * *aSearchPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP inFileSearch::SetSearchPath(nsIFile * aSearchPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean searchRecursive; */
NS_IMETHODIMP inFileSearch::GetSearchRecursive(PRBool *aSearchRecursive)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP inFileSearch::SetSearchRecursive(PRBool aSearchRecursive)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned long directoriesSearched; */
NS_IMETHODIMP inFileSearch::GetDirectoriesSearched(PRUint32 *aDirectoriesSearched)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIFile currentDirectory; */
NS_IMETHODIMP inFileSearch::GetCurrentDirectory(nsIFile * *aCurrentDirectory)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIFile getFileResultAt (in long aIndex); */
NS_IMETHODIMP inFileSearch::GetFileResultAt(PRInt32 aIndex, nsIFile **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_inIFileSearch_h__ */
