/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgBiffManager.idl
 */

#ifndef __gen_nsIMsgBiffManager_h__
#define __gen_nsIMsgBiffManager_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgIncomingServer_h__
#include "nsIMsgIncomingServer.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgBiffManager */
#define NS_IMSGBIFFMANAGER_IID_STR "17275d52-1622-11d3-8a84-0060b0fc04d2"

#define NS_IMSGBIFFMANAGER_IID \
  {0x17275d52, 0x1622, 0x11d3, \
    { 0x8a, 0x84, 0x00, 0x60, 0xb0, 0xfc, 0x04, 0xd2 }}

class NS_NO_VTABLE nsIMsgBiffManager : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGBIFFMANAGER_IID)

  /* void init (); */
  NS_IMETHOD Init(void) = 0;

  /* void addServerBiff (in nsIMsgIncomingServer server); */
  NS_IMETHOD AddServerBiff(nsIMsgIncomingServer *server) = 0;

  /* void removeServerBiff (in nsIMsgIncomingServer server); */
  NS_IMETHOD RemoveServerBiff(nsIMsgIncomingServer *server) = 0;

  /* void forceBiff (in nsIMsgIncomingServer server); */
  NS_IMETHOD ForceBiff(nsIMsgIncomingServer *server) = 0;

  /* void forceBiffAll (); */
  NS_IMETHOD ForceBiffAll(void) = 0;

  /* void shutdown (); */
  NS_IMETHOD Shutdown(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGBIFFMANAGER \
  NS_IMETHOD Init(void); \
  NS_IMETHOD AddServerBiff(nsIMsgIncomingServer *server); \
  NS_IMETHOD RemoveServerBiff(nsIMsgIncomingServer *server); \
  NS_IMETHOD ForceBiff(nsIMsgIncomingServer *server); \
  NS_IMETHOD ForceBiffAll(void); \
  NS_IMETHOD Shutdown(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGBIFFMANAGER(_to) \
  NS_IMETHOD Init(void) { return _to Init(); } \
  NS_IMETHOD AddServerBiff(nsIMsgIncomingServer *server) { return _to AddServerBiff(server); } \
  NS_IMETHOD RemoveServerBiff(nsIMsgIncomingServer *server) { return _to RemoveServerBiff(server); } \
  NS_IMETHOD ForceBiff(nsIMsgIncomingServer *server) { return _to ForceBiff(server); } \
  NS_IMETHOD ForceBiffAll(void) { return _to ForceBiffAll(); } \
  NS_IMETHOD Shutdown(void) { return _to Shutdown(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGBIFFMANAGER(_to) \
  NS_IMETHOD Init(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(); } \
  NS_IMETHOD AddServerBiff(nsIMsgIncomingServer *server) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddServerBiff(server); } \
  NS_IMETHOD RemoveServerBiff(nsIMsgIncomingServer *server) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveServerBiff(server); } \
  NS_IMETHOD ForceBiff(nsIMsgIncomingServer *server) { return !_to ? NS_ERROR_NULL_POINTER : _to->ForceBiff(server); } \
  NS_IMETHOD ForceBiffAll(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ForceBiffAll(); } \
  NS_IMETHOD Shutdown(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Shutdown(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgBiffManager : public nsIMsgBiffManager
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGBIFFMANAGER

  nsMsgBiffManager();

private:
  ~nsMsgBiffManager();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgBiffManager, nsIMsgBiffManager)

nsMsgBiffManager::nsMsgBiffManager()
{
  /* member initializers and constructor code */
}

nsMsgBiffManager::~nsMsgBiffManager()
{
  /* destructor code */
}

/* void init (); */
NS_IMETHODIMP nsMsgBiffManager::Init()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addServerBiff (in nsIMsgIncomingServer server); */
NS_IMETHODIMP nsMsgBiffManager::AddServerBiff(nsIMsgIncomingServer *server)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeServerBiff (in nsIMsgIncomingServer server); */
NS_IMETHODIMP nsMsgBiffManager::RemoveServerBiff(nsIMsgIncomingServer *server)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void forceBiff (in nsIMsgIncomingServer server); */
NS_IMETHODIMP nsMsgBiffManager::ForceBiff(nsIMsgIncomingServer *server)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void forceBiffAll (); */
NS_IMETHODIMP nsMsgBiffManager::ForceBiffAll()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void shutdown (); */
NS_IMETHODIMP nsMsgBiffManager::Shutdown()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgBiffManager_h__ */
