/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgStatusFeedback.idl
 */

#ifndef __gen_nsIMsgStatusFeedback_h__
#define __gen_nsIMsgStatusFeedback_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDocShell; /* forward declaration */

class nsIDOMWindow; /* forward declaration */


/* starting interface:    nsIMsgStatusFeedback */
#define NS_IMSGSTATUSFEEDBACK_IID_STR "a0032cf0-49e9-11d3-8d77-00805f8a6617"

#define NS_IMSGSTATUSFEEDBACK_IID \
  {0xa0032cf0, 0x49e9, 0x11d3, \
    { 0x8d, 0x77, 0x00, 0x80, 0x5f, 0x8a, 0x66, 0x17 }}

class NS_NO_VTABLE nsIMsgStatusFeedback : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGSTATUSFEEDBACK_IID)

  /* void showStatusString (in wstring status); */
  NS_IMETHOD ShowStatusString(const PRUnichar *status) = 0;

  /* void startMeteors (); */
  NS_IMETHOD StartMeteors(void) = 0;

  /* void stopMeteors (); */
  NS_IMETHOD StopMeteors(void) = 0;

  /* void showProgress (in long percent); */
  NS_IMETHOD ShowProgress(PRInt32 percent) = 0;

  /* void setStatusString (in wstring status); */
  NS_IMETHOD SetStatusString(const PRUnichar *status) = 0;

  /* [noscript] void setDocShell (in nsIDocShell shell, in nsIDOMWindow window); */
  NS_IMETHOD SetDocShell(nsIDocShell *shell, nsIDOMWindow *window) = 0;

  /* void closeWindow (); */
  NS_IMETHOD CloseWindow(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSTATUSFEEDBACK \
  NS_IMETHOD ShowStatusString(const PRUnichar *status); \
  NS_IMETHOD StartMeteors(void); \
  NS_IMETHOD StopMeteors(void); \
  NS_IMETHOD ShowProgress(PRInt32 percent); \
  NS_IMETHOD SetStatusString(const PRUnichar *status); \
  NS_IMETHOD SetDocShell(nsIDocShell *shell, nsIDOMWindow *window); \
  NS_IMETHOD CloseWindow(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSTATUSFEEDBACK(_to) \
  NS_IMETHOD ShowStatusString(const PRUnichar *status) { return _to ShowStatusString(status); } \
  NS_IMETHOD StartMeteors(void) { return _to StartMeteors(); } \
  NS_IMETHOD StopMeteors(void) { return _to StopMeteors(); } \
  NS_IMETHOD ShowProgress(PRInt32 percent) { return _to ShowProgress(percent); } \
  NS_IMETHOD SetStatusString(const PRUnichar *status) { return _to SetStatusString(status); } \
  NS_IMETHOD SetDocShell(nsIDocShell *shell, nsIDOMWindow *window) { return _to SetDocShell(shell, window); } \
  NS_IMETHOD CloseWindow(void) { return _to CloseWindow(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSTATUSFEEDBACK(_to) \
  NS_IMETHOD ShowStatusString(const PRUnichar *status) { return !_to ? NS_ERROR_NULL_POINTER : _to->ShowStatusString(status); } \
  NS_IMETHOD StartMeteors(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->StartMeteors(); } \
  NS_IMETHOD StopMeteors(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->StopMeteors(); } \
  NS_IMETHOD ShowProgress(PRInt32 percent) { return !_to ? NS_ERROR_NULL_POINTER : _to->ShowProgress(percent); } \
  NS_IMETHOD SetStatusString(const PRUnichar *status) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetStatusString(status); } \
  NS_IMETHOD SetDocShell(nsIDocShell *shell, nsIDOMWindow *window) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDocShell(shell, window); } \
  NS_IMETHOD CloseWindow(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CloseWindow(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgStatusFeedback : public nsIMsgStatusFeedback
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSTATUSFEEDBACK

  nsMsgStatusFeedback();

private:
  ~nsMsgStatusFeedback();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgStatusFeedback, nsIMsgStatusFeedback)

nsMsgStatusFeedback::nsMsgStatusFeedback()
{
  /* member initializers and constructor code */
}

nsMsgStatusFeedback::~nsMsgStatusFeedback()
{
  /* destructor code */
}

/* void showStatusString (in wstring status); */
NS_IMETHODIMP nsMsgStatusFeedback::ShowStatusString(const PRUnichar *status)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void startMeteors (); */
NS_IMETHODIMP nsMsgStatusFeedback::StartMeteors()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void stopMeteors (); */
NS_IMETHODIMP nsMsgStatusFeedback::StopMeteors()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void showProgress (in long percent); */
NS_IMETHODIMP nsMsgStatusFeedback::ShowProgress(PRInt32 percent)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setStatusString (in wstring status); */
NS_IMETHODIMP nsMsgStatusFeedback::SetStatusString(const PRUnichar *status)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void setDocShell (in nsIDocShell shell, in nsIDOMWindow window); */
NS_IMETHODIMP nsMsgStatusFeedback::SetDocShell(nsIDocShell *shell, nsIDOMWindow *window)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void closeWindow (); */
NS_IMETHODIMP nsMsgStatusFeedback::CloseWindow()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgStatusFeedback_h__ */
