/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIUrlClassifierUtils.idl
 */

#ifndef __gen_nsIUrlClassifierUtils_h__
#define __gen_nsIUrlClassifierUtils_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIUrlClassifierUtils */
#define NS_IURLCLASSIFIERUTILS_IID_STR "9afd3add-eadc-409f-a187-e3bf60e47290"

#define NS_IURLCLASSIFIERUTILS_IID \
  {0x9afd3add, 0xeadc, 0x409f, \
    { 0xa1, 0x87, 0xe3, 0xbf, 0x60, 0xe4, 0x72, 0x90 }}

/**
 * Some utility methods used by the url classifier.
 */
class NS_NO_VTABLE nsIUrlClassifierUtils : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IURLCLASSIFIERUTILS_IID)

  /**
   * Canonicalize a URL.  DON'T USE THIS DIRECTLY.  Use
   * PROT_EnchashDecrypter.prototype.getCanonicalUrl instead.  This method
   * url-decodes a string, but it doesn't normalize the hostname.  The method
   * in EnchashDecrypter first calls this method, then normalizes the hostname.
   *
   * @param url String to canonicalize
   *
   * @returns String containing the canonicalized url (maximally url-decoded,
   *          then specially url-encoded)
   */
  /* ACString canonicalizeURL (in ACString url); */
  NS_IMETHOD CanonicalizeURL(const nsACString & url, nsACString & _retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIURLCLASSIFIERUTILS \
  NS_IMETHOD CanonicalizeURL(const nsACString & url, nsACString & _retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIURLCLASSIFIERUTILS(_to) \
  NS_IMETHOD CanonicalizeURL(const nsACString & url, nsACString & _retval) { return _to CanonicalizeURL(url, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIURLCLASSIFIERUTILS(_to) \
  NS_IMETHOD CanonicalizeURL(const nsACString & url, nsACString & _retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CanonicalizeURL(url, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsUrlClassifierUtils : public nsIUrlClassifierUtils
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIURLCLASSIFIERUTILS

  nsUrlClassifierUtils();

private:
  ~nsUrlClassifierUtils();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsUrlClassifierUtils, nsIUrlClassifierUtils)

nsUrlClassifierUtils::nsUrlClassifierUtils()
{
  /* member initializers and constructor code */
}

nsUrlClassifierUtils::~nsUrlClassifierUtils()
{
  /* destructor code */
}

/* ACString canonicalizeURL (in ACString url); */
NS_IMETHODIMP nsUrlClassifierUtils::CanonicalizeURL(const nsACString & url, nsACString & _retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIUrlClassifierUtils_h__ */
