/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/*

  Interface for importing mail - ui provided by the import module.  If
  you wish to provide your own UI then implement the nsIImportGeneric
  interface.
  
 */

#include "nsISupports.idl"

interface nsIFileSpec;

[scriptable, uuid(d92056c0-184d-11d3-a206-00a0cc26da63)]
interface nsIImportMailboxDescriptor : nsISupports
{	
	attribute unsigned long 		identifier;
	attribute unsigned long			depth;
	attribute unsigned long			size;
	
	wstring	GetDisplayName();
	void	SetDisplayName( [const] in wstring name);
	
	attribute boolean				import;
	readonly attribute nsIFileSpec	fileSpec;
};
	


%{ C++

/*
	The default implementation can be obtained from
	nsIImportService::CreateNewMailboxDescriptor();
	
	You should only be interested in using this class if you implement
	the nsIImportMail interface in which case, just using the service to
	create new ones should work fine for you.  If not, implement your
	own.
*/

%}
