/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIUrlListenerManager.idl
 */

#ifndef __gen_nsIUrlListenerManager_h__
#define __gen_nsIUrlListenerManager_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIUrlListener_h__
#include "nsIUrlListener.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgMailNewsUrl; /* forward declaration */

#include "nsIMsgMailNewsUrl.h"

/* starting interface:    nsIUrlListenerManager */
#define NS_IURLLISTENERMANAGER_IID_STR "5bcdb610-d00d-11d2-8069-006008128c4e"

#define NS_IURLLISTENERMANAGER_IID \
  {0x5bcdb610, 0xd00d, 0x11d2, \
    { 0x80, 0x69, 0x00, 0x60, 0x08, 0x12, 0x8c, 0x4e }}

class NS_NO_VTABLE nsIUrlListenerManager : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IURLLISTENERMANAGER_IID)

  /* void RegisterListener (in nsIUrlListener aUrlListener); */
  NS_IMETHOD RegisterListener(nsIUrlListener *aUrlListener) = 0;

  /* void UnRegisterListener (in nsIUrlListener aUrlListener); */
  NS_IMETHOD UnRegisterListener(nsIUrlListener *aUrlListener) = 0;

  /* void OnStartRunningUrl (in nsIMsgMailNewsUrl aUrl); */
  NS_IMETHOD OnStartRunningUrl(nsIMsgMailNewsUrl *aUrl) = 0;

  /* void OnStopRunningUrl (in nsIMsgMailNewsUrl aUrl, in nsresult aExitCode); */
  NS_IMETHOD OnStopRunningUrl(nsIMsgMailNewsUrl *aUrl, nsresult aExitCode) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIURLLISTENERMANAGER \
  NS_IMETHOD RegisterListener(nsIUrlListener *aUrlListener); \
  NS_IMETHOD UnRegisterListener(nsIUrlListener *aUrlListener); \
  NS_IMETHOD OnStartRunningUrl(nsIMsgMailNewsUrl *aUrl); \
  NS_IMETHOD OnStopRunningUrl(nsIMsgMailNewsUrl *aUrl, nsresult aExitCode); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIURLLISTENERMANAGER(_to) \
  NS_IMETHOD RegisterListener(nsIUrlListener *aUrlListener) { return _to RegisterListener(aUrlListener); } \
  NS_IMETHOD UnRegisterListener(nsIUrlListener *aUrlListener) { return _to UnRegisterListener(aUrlListener); } \
  NS_IMETHOD OnStartRunningUrl(nsIMsgMailNewsUrl *aUrl) { return _to OnStartRunningUrl(aUrl); } \
  NS_IMETHOD OnStopRunningUrl(nsIMsgMailNewsUrl *aUrl, nsresult aExitCode) { return _to OnStopRunningUrl(aUrl, aExitCode); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIURLLISTENERMANAGER(_to) \
  NS_IMETHOD RegisterListener(nsIUrlListener *aUrlListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RegisterListener(aUrlListener); } \
  NS_IMETHOD UnRegisterListener(nsIUrlListener *aUrlListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->UnRegisterListener(aUrlListener); } \
  NS_IMETHOD OnStartRunningUrl(nsIMsgMailNewsUrl *aUrl) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStartRunningUrl(aUrl); } \
  NS_IMETHOD OnStopRunningUrl(nsIMsgMailNewsUrl *aUrl, nsresult aExitCode) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnStopRunningUrl(aUrl, aExitCode); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsUrlListenerManager : public nsIUrlListenerManager
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIURLLISTENERMANAGER

  nsUrlListenerManager();

private:
  ~nsUrlListenerManager();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsUrlListenerManager, nsIUrlListenerManager)

nsUrlListenerManager::nsUrlListenerManager()
{
  /* member initializers and constructor code */
}

nsUrlListenerManager::~nsUrlListenerManager()
{
  /* destructor code */
}

/* void RegisterListener (in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsUrlListenerManager::RegisterListener(nsIUrlListener *aUrlListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void UnRegisterListener (in nsIUrlListener aUrlListener); */
NS_IMETHODIMP nsUrlListenerManager::UnRegisterListener(nsIUrlListener *aUrlListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnStartRunningUrl (in nsIMsgMailNewsUrl aUrl); */
NS_IMETHODIMP nsUrlListenerManager::OnStartRunningUrl(nsIMsgMailNewsUrl *aUrl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OnStopRunningUrl (in nsIMsgMailNewsUrl aUrl, in nsresult aExitCode); */
NS_IMETHODIMP nsUrlListenerManager::OnStopRunningUrl(nsIMsgMailNewsUrl *aUrl, nsresult aExitCode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIUrlListenerManager_h__ */
