/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMimeHeaders.idl
 */

#ifndef __gen_nsIMimeHeaders_h__
#define __gen_nsIMimeHeaders_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsrootidl_h__
#include "nsrootidl.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
#define NS_IMIMEHEADERS_CONTRACTID \
  "@mozilla.org/messenger/mimeheaders;1"
// {9C4DA772-07EB-11d3-8EE5-00A024669799}
#define NS_IMIMEHEADERS_CID \
    { 0x13e16677, 0x6648, 0x11d3, \
    { 0xa7, 0x2f, 0x0, 0x60, 0xb0, 0xeb, 0x39, 0xb5 } }

/* starting interface:    nsIMimeHeaders */
#define NS_IMIMEHEADERS_IID_STR "13e16676-6648-11d3-a72f-0060b0eb39b5"

#define NS_IMIMEHEADERS_IID \
  {0x13e16676, 0x6648, 0x11d3, \
    { 0xa7, 0x2f, 0x00, 0x60, 0xb0, 0xeb, 0x39, 0xb5 }}

class NS_NO_VTABLE nsIMimeHeaders : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMIMEHEADERS_IID)

  /* void initialize ([const] in string allHeaders, in long allHeadersSize); */
  NS_IMETHOD Initialize(const char *allHeaders, PRInt32 allHeadersSize) = 0;

  /* string extractHeader ([const] in string headerName, in boolean getAllOfThem); */
  NS_IMETHOD ExtractHeader(const char *headerName, PRBool getAllOfThem, char **_retval) = 0;

  /* readonly attribute string allHeaders; */
  NS_IMETHOD GetAllHeaders(char * *aAllHeaders) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMIMEHEADERS \
  NS_IMETHOD Initialize(const char *allHeaders, PRInt32 allHeadersSize); \
  NS_IMETHOD ExtractHeader(const char *headerName, PRBool getAllOfThem, char **_retval); \
  NS_IMETHOD GetAllHeaders(char * *aAllHeaders); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMIMEHEADERS(_to) \
  NS_IMETHOD Initialize(const char *allHeaders, PRInt32 allHeadersSize) { return _to Initialize(allHeaders, allHeadersSize); } \
  NS_IMETHOD ExtractHeader(const char *headerName, PRBool getAllOfThem, char **_retval) { return _to ExtractHeader(headerName, getAllOfThem, _retval); } \
  NS_IMETHOD GetAllHeaders(char * *aAllHeaders) { return _to GetAllHeaders(aAllHeaders); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMIMEHEADERS(_to) \
  NS_IMETHOD Initialize(const char *allHeaders, PRInt32 allHeadersSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->Initialize(allHeaders, allHeadersSize); } \
  NS_IMETHOD ExtractHeader(const char *headerName, PRBool getAllOfThem, char **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ExtractHeader(headerName, getAllOfThem, _retval); } \
  NS_IMETHOD GetAllHeaders(char * *aAllHeaders) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAllHeaders(aAllHeaders); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMimeHeaders : public nsIMimeHeaders
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMIMEHEADERS

  nsMimeHeaders();

private:
  ~nsMimeHeaders();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMimeHeaders, nsIMimeHeaders)

nsMimeHeaders::nsMimeHeaders()
{
  /* member initializers and constructor code */
}

nsMimeHeaders::~nsMimeHeaders()
{
  /* destructor code */
}

/* void initialize ([const] in string allHeaders, in long allHeadersSize); */
NS_IMETHODIMP nsMimeHeaders::Initialize(const char *allHeaders, PRInt32 allHeadersSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* string extractHeader ([const] in string headerName, in boolean getAllOfThem); */
NS_IMETHODIMP nsMimeHeaders::ExtractHeader(const char *headerName, PRBool getAllOfThem, char **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string allHeaders; */
NS_IMETHODIMP nsMimeHeaders::GetAllHeaders(char * *aAllHeaders)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

nsresult NS_NewMimeHeaders(const nsIID &aIID, void ** aInstancePtrResult);

#endif /* __gen_nsIMimeHeaders_h__ */
