/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgComposeService.idl
 */

#ifndef __gen_nsIMsgComposeService_h__
#define __gen_nsIMsgComposeService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgCompose_h__
#include "nsIMsgCompose.h"
#endif

#ifndef __gen_nsIMsgComposeParams_h__
#include "nsIMsgComposeParams.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIURI; /* forward declaration */

class nsIDOMWindowInternal; /* forward declaration */

class nsIMsgWindow; /* forward declaration */

class nsIMsgIdentity; /* forward declaration */

class nsIMsgIncomingServer; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */


/* starting interface:    nsIMsgComposeService */
#define NS_IMSGCOMPOSESERVICE_IID_STR "bc1c0379-82ef-45ae-9710-dd4fa93252f7"

#define NS_IMSGCOMPOSESERVICE_IID \
  {0xbc1c0379, 0x82ef, 0x45ae, \
    { 0x97, 0x10, 0xdd, 0x4f, 0xa9, 0x32, 0x52, 0xf7 }}

class NS_NO_VTABLE nsIMsgComposeService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGCOMPOSESERVICE_IID)

  /* void OpenComposeWindow (in string msgComposeWindowURL, in string originalMsgURI, in MSG_ComposeType type, in MSG_ComposeFormat format, in nsIMsgIdentity identity, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD OpenComposeWindow(const char *msgComposeWindowURL, const char *originalMsgURI, MSG_ComposeType type, MSG_ComposeFormat format, nsIMsgIdentity *identity, nsIMsgWindow *aMsgWindow) = 0;

  /* void OpenComposeWindowWithURI (in string msgComposeWindowURL, in nsIURI aURI); */
  NS_IMETHOD OpenComposeWindowWithURI(const char *msgComposeWindowURL, nsIURI *aURI) = 0;

  /* void OpenComposeWindowWithParams (in string msgComposeWindowURL, in nsIMsgComposeParams params); */
  NS_IMETHOD OpenComposeWindowWithParams(const char *msgComposeWindowURL, nsIMsgComposeParams *params) = 0;

  /* nsIMsgCompose InitCompose (in nsIDOMWindowInternal aWindow, in nsIMsgComposeParams params); */
  NS_IMETHOD InitCompose(nsIDOMWindowInternal *aWindow, nsIMsgComposeParams *params, nsIMsgCompose **_retval) = 0;

  /**
  * defaultIdentity
  *
  * @return the default identity, in case no identity has been setup yet, will return null
  */
  /* readonly attribute nsIMsgIdentity defaultIdentity; */
  NS_IMETHOD GetDefaultIdentity(nsIMsgIdentity * *aDefaultIdentity) = 0;

  /* void TimeStamp (in string label, in boolean resetTime); */
  NS_IMETHOD TimeStamp(const char *label, PRBool resetTime) = 0;

  /* readonly attribute boolean logComposePerformance; */
  NS_IMETHOD GetLogComposePerformance(PRBool *aLogComposePerformance) = 0;

  /* [noscript] boolean determineComposeHTML (in nsIMsgIdentity aIdentity, in MSG_ComposeFormat aFormat); */
  NS_IMETHOD DetermineComposeHTML(nsIMsgIdentity *aIdentity, MSG_ComposeFormat aFormat, PRBool *_retval) = 0;

  /* [noscript] void cacheWindow (in nsIDOMWindowInternal aWindow, in boolean aComposeHTML, in nsIMsgComposeRecyclingListener listener); */
  NS_IMETHOD CacheWindow(nsIDOMWindowInternal *aWindow, PRBool aComposeHTML, nsIMsgComposeRecyclingListener *listener) = 0;

  /* boolean isCachedWindow (in nsIDOMWindowInternal aWindow); */
  NS_IMETHOD IsCachedWindow(nsIDOMWindowInternal *aWindow, PRBool *_retval) = 0;

  /** 
   * given a mailto url, parse the attributes and turn them into a nsIMsgComposeParams object
   * @return nsIMsgComposeParams which corresponds to the passed in mailto url
   */
  /* nsIMsgComposeParams getParamsForMailto (in nsIURI aURI); */
  NS_IMETHOD GetParamsForMailto(nsIURI *aURI, nsIMsgComposeParams **_retval) = 0;

  /* void forwardMessage (in AString forwardTo, in nsIMsgDBHdr aMsgHdr, in nsIMsgWindow aMsgWindow, in nsIMsgIncomingServer aServer); */
  NS_IMETHOD ForwardMessage(const nsAString & forwardTo, nsIMsgDBHdr *aMsgHdr, nsIMsgWindow *aMsgWindow, nsIMsgIncomingServer *aServer) = 0;

  /* void replyWithTemplate (in nsIMsgDBHdr msgHdr, in string templateUri, in nsIMsgWindow aMsgWindow, in nsIMsgIncomingServer server); */
  NS_IMETHOD ReplyWithTemplate(nsIMsgDBHdr *msgHdr, const char *templateUri, nsIMsgWindow *aMsgWindow, nsIMsgIncomingServer *server) = 0;

  /** 
   * Every open compose window registers itself with the compose service 
   * This allows consumers to get the msg compose object associated with a dom window
   *
   * @param aWindow The DOM Window 
   * @param aMsgCompose The compose object associated with the compose window
   *
   */
  /* void registerComposeWindow (in nsIDOMWindowInternal aWindow, in nsIMsgCompose aMsgCompose); */
  NS_IMETHOD RegisterComposeWindow(nsIDOMWindowInternal *aWindow, nsIMsgCompose *aMsgCompose) = 0;

  /** 
   * When a compose window is being closed (or recyled), it unregisters itself
   * from the compose service. 
   *
   * @param aWindow The DOM Window 
   *
   */
  /* void unregisterComposeWindow (in nsIDOMWindowInternal aWindow); */
  NS_IMETHOD UnregisterComposeWindow(nsIDOMWindowInternal *aWindow) = 0;

  /**
   * For aWindow, returns the nsIMsgCompose object associated with the window.
   *
   * @param aWindow The DOMWindow associated with the compose window.
   *
   * @return NS_ERROR_FAILURE if we could not find a nsIMsgCompose for the passed in
   *         DOM Window.
   */
  /* nsIMsgCompose getMsgComposeForWindow (in nsIDOMWindowInternal aWindow); */
  NS_IMETHOD GetMsgComposeForWindow(nsIDOMWindowInternal *aWindow, nsIMsgCompose **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGCOMPOSESERVICE \
  NS_IMETHOD OpenComposeWindow(const char *msgComposeWindowURL, const char *originalMsgURI, MSG_ComposeType type, MSG_ComposeFormat format, nsIMsgIdentity *identity, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD OpenComposeWindowWithURI(const char *msgComposeWindowURL, nsIURI *aURI); \
  NS_IMETHOD OpenComposeWindowWithParams(const char *msgComposeWindowURL, nsIMsgComposeParams *params); \
  NS_IMETHOD InitCompose(nsIDOMWindowInternal *aWindow, nsIMsgComposeParams *params, nsIMsgCompose **_retval); \
  NS_IMETHOD GetDefaultIdentity(nsIMsgIdentity * *aDefaultIdentity); \
  NS_IMETHOD TimeStamp(const char *label, PRBool resetTime); \
  NS_IMETHOD GetLogComposePerformance(PRBool *aLogComposePerformance); \
  NS_IMETHOD DetermineComposeHTML(nsIMsgIdentity *aIdentity, MSG_ComposeFormat aFormat, PRBool *_retval); \
  NS_IMETHOD CacheWindow(nsIDOMWindowInternal *aWindow, PRBool aComposeHTML, nsIMsgComposeRecyclingListener *listener); \
  NS_IMETHOD IsCachedWindow(nsIDOMWindowInternal *aWindow, PRBool *_retval); \
  NS_IMETHOD GetParamsForMailto(nsIURI *aURI, nsIMsgComposeParams **_retval); \
  NS_IMETHOD ForwardMessage(const nsAString & forwardTo, nsIMsgDBHdr *aMsgHdr, nsIMsgWindow *aMsgWindow, nsIMsgIncomingServer *aServer); \
  NS_IMETHOD ReplyWithTemplate(nsIMsgDBHdr *msgHdr, const char *templateUri, nsIMsgWindow *aMsgWindow, nsIMsgIncomingServer *server); \
  NS_IMETHOD RegisterComposeWindow(nsIDOMWindowInternal *aWindow, nsIMsgCompose *aMsgCompose); \
  NS_IMETHOD UnregisterComposeWindow(nsIDOMWindowInternal *aWindow); \
  NS_IMETHOD GetMsgComposeForWindow(nsIDOMWindowInternal *aWindow, nsIMsgCompose **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGCOMPOSESERVICE(_to) \
  NS_IMETHOD OpenComposeWindow(const char *msgComposeWindowURL, const char *originalMsgURI, MSG_ComposeType type, MSG_ComposeFormat format, nsIMsgIdentity *identity, nsIMsgWindow *aMsgWindow) { return _to OpenComposeWindow(msgComposeWindowURL, originalMsgURI, type, format, identity, aMsgWindow); } \
  NS_IMETHOD OpenComposeWindowWithURI(const char *msgComposeWindowURL, nsIURI *aURI) { return _to OpenComposeWindowWithURI(msgComposeWindowURL, aURI); } \
  NS_IMETHOD OpenComposeWindowWithParams(const char *msgComposeWindowURL, nsIMsgComposeParams *params) { return _to OpenComposeWindowWithParams(msgComposeWindowURL, params); } \
  NS_IMETHOD InitCompose(nsIDOMWindowInternal *aWindow, nsIMsgComposeParams *params, nsIMsgCompose **_retval) { return _to InitCompose(aWindow, params, _retval); } \
  NS_IMETHOD GetDefaultIdentity(nsIMsgIdentity * *aDefaultIdentity) { return _to GetDefaultIdentity(aDefaultIdentity); } \
  NS_IMETHOD TimeStamp(const char *label, PRBool resetTime) { return _to TimeStamp(label, resetTime); } \
  NS_IMETHOD GetLogComposePerformance(PRBool *aLogComposePerformance) { return _to GetLogComposePerformance(aLogComposePerformance); } \
  NS_IMETHOD DetermineComposeHTML(nsIMsgIdentity *aIdentity, MSG_ComposeFormat aFormat, PRBool *_retval) { return _to DetermineComposeHTML(aIdentity, aFormat, _retval); } \
  NS_IMETHOD CacheWindow(nsIDOMWindowInternal *aWindow, PRBool aComposeHTML, nsIMsgComposeRecyclingListener *listener) { return _to CacheWindow(aWindow, aComposeHTML, listener); } \
  NS_IMETHOD IsCachedWindow(nsIDOMWindowInternal *aWindow, PRBool *_retval) { return _to IsCachedWindow(aWindow, _retval); } \
  NS_IMETHOD GetParamsForMailto(nsIURI *aURI, nsIMsgComposeParams **_retval) { return _to GetParamsForMailto(aURI, _retval); } \
  NS_IMETHOD ForwardMessage(const nsAString & forwardTo, nsIMsgDBHdr *aMsgHdr, nsIMsgWindow *aMsgWindow, nsIMsgIncomingServer *aServer) { return _to ForwardMessage(forwardTo, aMsgHdr, aMsgWindow, aServer); } \
  NS_IMETHOD ReplyWithTemplate(nsIMsgDBHdr *msgHdr, const char *templateUri, nsIMsgWindow *aMsgWindow, nsIMsgIncomingServer *server) { return _to ReplyWithTemplate(msgHdr, templateUri, aMsgWindow, server); } \
  NS_IMETHOD RegisterComposeWindow(nsIDOMWindowInternal *aWindow, nsIMsgCompose *aMsgCompose) { return _to RegisterComposeWindow(aWindow, aMsgCompose); } \
  NS_IMETHOD UnregisterComposeWindow(nsIDOMWindowInternal *aWindow) { return _to UnregisterComposeWindow(aWindow); } \
  NS_IMETHOD GetMsgComposeForWindow(nsIDOMWindowInternal *aWindow, nsIMsgCompose **_retval) { return _to GetMsgComposeForWindow(aWindow, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGCOMPOSESERVICE(_to) \
  NS_IMETHOD OpenComposeWindow(const char *msgComposeWindowURL, const char *originalMsgURI, MSG_ComposeType type, MSG_ComposeFormat format, nsIMsgIdentity *identity, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->OpenComposeWindow(msgComposeWindowURL, originalMsgURI, type, format, identity, aMsgWindow); } \
  NS_IMETHOD OpenComposeWindowWithURI(const char *msgComposeWindowURL, nsIURI *aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->OpenComposeWindowWithURI(msgComposeWindowURL, aURI); } \
  NS_IMETHOD OpenComposeWindowWithParams(const char *msgComposeWindowURL, nsIMsgComposeParams *params) { return !_to ? NS_ERROR_NULL_POINTER : _to->OpenComposeWindowWithParams(msgComposeWindowURL, params); } \
  NS_IMETHOD InitCompose(nsIDOMWindowInternal *aWindow, nsIMsgComposeParams *params, nsIMsgCompose **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->InitCompose(aWindow, params, _retval); } \
  NS_IMETHOD GetDefaultIdentity(nsIMsgIdentity * *aDefaultIdentity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultIdentity(aDefaultIdentity); } \
  NS_IMETHOD TimeStamp(const char *label, PRBool resetTime) { return !_to ? NS_ERROR_NULL_POINTER : _to->TimeStamp(label, resetTime); } \
  NS_IMETHOD GetLogComposePerformance(PRBool *aLogComposePerformance) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLogComposePerformance(aLogComposePerformance); } \
  NS_IMETHOD DetermineComposeHTML(nsIMsgIdentity *aIdentity, MSG_ComposeFormat aFormat, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->DetermineComposeHTML(aIdentity, aFormat, _retval); } \
  NS_IMETHOD CacheWindow(nsIDOMWindowInternal *aWindow, PRBool aComposeHTML, nsIMsgComposeRecyclingListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->CacheWindow(aWindow, aComposeHTML, listener); } \
  NS_IMETHOD IsCachedWindow(nsIDOMWindowInternal *aWindow, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsCachedWindow(aWindow, _retval); } \
  NS_IMETHOD GetParamsForMailto(nsIURI *aURI, nsIMsgComposeParams **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetParamsForMailto(aURI, _retval); } \
  NS_IMETHOD ForwardMessage(const nsAString & forwardTo, nsIMsgDBHdr *aMsgHdr, nsIMsgWindow *aMsgWindow, nsIMsgIncomingServer *aServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->ForwardMessage(forwardTo, aMsgHdr, aMsgWindow, aServer); } \
  NS_IMETHOD ReplyWithTemplate(nsIMsgDBHdr *msgHdr, const char *templateUri, nsIMsgWindow *aMsgWindow, nsIMsgIncomingServer *server) { return !_to ? NS_ERROR_NULL_POINTER : _to->ReplyWithTemplate(msgHdr, templateUri, aMsgWindow, server); } \
  NS_IMETHOD RegisterComposeWindow(nsIDOMWindowInternal *aWindow, nsIMsgCompose *aMsgCompose) { return !_to ? NS_ERROR_NULL_POINTER : _to->RegisterComposeWindow(aWindow, aMsgCompose); } \
  NS_IMETHOD UnregisterComposeWindow(nsIDOMWindowInternal *aWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->UnregisterComposeWindow(aWindow); } \
  NS_IMETHOD GetMsgComposeForWindow(nsIDOMWindowInternal *aWindow, nsIMsgCompose **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgComposeForWindow(aWindow, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgComposeService : public nsIMsgComposeService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGCOMPOSESERVICE

  nsMsgComposeService();

private:
  ~nsMsgComposeService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgComposeService, nsIMsgComposeService)

nsMsgComposeService::nsMsgComposeService()
{
  /* member initializers and constructor code */
}

nsMsgComposeService::~nsMsgComposeService()
{
  /* destructor code */
}

/* void OpenComposeWindow (in string msgComposeWindowURL, in string originalMsgURI, in MSG_ComposeType type, in MSG_ComposeFormat format, in nsIMsgIdentity identity, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgComposeService::OpenComposeWindow(const char *msgComposeWindowURL, const char *originalMsgURI, MSG_ComposeType type, MSG_ComposeFormat format, nsIMsgIdentity *identity, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OpenComposeWindowWithURI (in string msgComposeWindowURL, in nsIURI aURI); */
NS_IMETHODIMP nsMsgComposeService::OpenComposeWindowWithURI(const char *msgComposeWindowURL, nsIURI *aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void OpenComposeWindowWithParams (in string msgComposeWindowURL, in nsIMsgComposeParams params); */
NS_IMETHODIMP nsMsgComposeService::OpenComposeWindowWithParams(const char *msgComposeWindowURL, nsIMsgComposeParams *params)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgCompose InitCompose (in nsIDOMWindowInternal aWindow, in nsIMsgComposeParams params); */
NS_IMETHODIMP nsMsgComposeService::InitCompose(nsIDOMWindowInternal *aWindow, nsIMsgComposeParams *params, nsIMsgCompose **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIMsgIdentity defaultIdentity; */
NS_IMETHODIMP nsMsgComposeService::GetDefaultIdentity(nsIMsgIdentity * *aDefaultIdentity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void TimeStamp (in string label, in boolean resetTime); */
NS_IMETHODIMP nsMsgComposeService::TimeStamp(const char *label, PRBool resetTime)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean logComposePerformance; */
NS_IMETHODIMP nsMsgComposeService::GetLogComposePerformance(PRBool *aLogComposePerformance)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] boolean determineComposeHTML (in nsIMsgIdentity aIdentity, in MSG_ComposeFormat aFormat); */
NS_IMETHODIMP nsMsgComposeService::DetermineComposeHTML(nsIMsgIdentity *aIdentity, MSG_ComposeFormat aFormat, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void cacheWindow (in nsIDOMWindowInternal aWindow, in boolean aComposeHTML, in nsIMsgComposeRecyclingListener listener); */
NS_IMETHODIMP nsMsgComposeService::CacheWindow(nsIDOMWindowInternal *aWindow, PRBool aComposeHTML, nsIMsgComposeRecyclingListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isCachedWindow (in nsIDOMWindowInternal aWindow); */
NS_IMETHODIMP nsMsgComposeService::IsCachedWindow(nsIDOMWindowInternal *aWindow, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgComposeParams getParamsForMailto (in nsIURI aURI); */
NS_IMETHODIMP nsMsgComposeService::GetParamsForMailto(nsIURI *aURI, nsIMsgComposeParams **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void forwardMessage (in AString forwardTo, in nsIMsgDBHdr aMsgHdr, in nsIMsgWindow aMsgWindow, in nsIMsgIncomingServer aServer); */
NS_IMETHODIMP nsMsgComposeService::ForwardMessage(const nsAString & forwardTo, nsIMsgDBHdr *aMsgHdr, nsIMsgWindow *aMsgWindow, nsIMsgIncomingServer *aServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void replyWithTemplate (in nsIMsgDBHdr msgHdr, in string templateUri, in nsIMsgWindow aMsgWindow, in nsIMsgIncomingServer server); */
NS_IMETHODIMP nsMsgComposeService::ReplyWithTemplate(nsIMsgDBHdr *msgHdr, const char *templateUri, nsIMsgWindow *aMsgWindow, nsIMsgIncomingServer *server)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void registerComposeWindow (in nsIDOMWindowInternal aWindow, in nsIMsgCompose aMsgCompose); */
NS_IMETHODIMP nsMsgComposeService::RegisterComposeWindow(nsIDOMWindowInternal *aWindow, nsIMsgCompose *aMsgCompose)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void unregisterComposeWindow (in nsIDOMWindowInternal aWindow); */
NS_IMETHODIMP nsMsgComposeService::UnregisterComposeWindow(nsIDOMWindowInternal *aWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgCompose getMsgComposeForWindow (in nsIDOMWindowInternal aWindow); */
NS_IMETHODIMP nsMsgComposeService::GetMsgComposeForWindow(nsIDOMWindowInternal *aWindow, nsIMsgCompose **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgComposeService_h__ */
