/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgMdnGenerator.idl
 */

#ifndef __gen_nsIMsgMdnGenerator_h__
#define __gen_nsIMsgMdnGenerator_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgWindow; /* forward declaration */

class nsIMsgFolder; /* forward declaration */

class nsIMimeHeaders; /* forward declaration */

typedef PRInt32 EDisposeType;

typedef PRInt32 ReceiptHdrType;

typedef PRInt32 MDNIncorporateType;

#define NS_MSGMDNGENERATOR_CONTRACTID \
  "@mozilla.org/messenger-mdn/generator;1"
#define NS_MSGMDNGENERATOR_CID                    \
{ /* ec917b13-8f73-4d4d-9146-d7f7aafe9076 */      \
 0xec917b13, 0x8f73, 0x4d4d,                      \
 { 0x91, 0x46, 0xd7, 0xf7, 0xaa, 0xfe, 0x90, 0x76 }}

/* starting interface:    nsIMsgMdnGenerator */
#define NS_IMSGMDNGENERATOR_IID_STR "b1658370-f4af-4b02-8052-3cfeb7dab10e"

#define NS_IMSGMDNGENERATOR_IID \
  {0xb1658370, 0xf4af, 0x4b02, \
    { 0x80, 0x52, 0x3c, 0xfe, 0xb7, 0xda, 0xb1, 0x0e }}

class NS_NO_VTABLE nsIMsgMdnGenerator : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGMDNGENERATOR_IID)

  enum { eDisplayed = 0 };

  enum { eDispatched = 1 };

  enum { eProcessed = 2 };

  enum { eDeleted = 3 };

  enum { eDenied = 4 };

  enum { eFailed = 5 };

  enum { eDntType = 0 };

  enum { eRrtType = 1 };

  enum { eDntRrtType = 2 };

  enum { eIncorporateInbox = 0 };

  enum { eIncorporateSent = 1 };

  /* void process (in EDisposeType eType, in nsIMsgWindow aWindow, in nsIMsgFolder folder, in nsMsgKey key, in nsIMimeHeaders headers, in boolean autoAction); */
  NS_IMETHOD Process(EDisposeType eType, nsIMsgWindow *aWindow, nsIMsgFolder *folder, nsMsgKey key, nsIMimeHeaders *headers, PRBool autoAction) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGMDNGENERATOR \
  NS_IMETHOD Process(EDisposeType eType, nsIMsgWindow *aWindow, nsIMsgFolder *folder, nsMsgKey key, nsIMimeHeaders *headers, PRBool autoAction); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGMDNGENERATOR(_to) \
  NS_IMETHOD Process(EDisposeType eType, nsIMsgWindow *aWindow, nsIMsgFolder *folder, nsMsgKey key, nsIMimeHeaders *headers, PRBool autoAction) { return _to Process(eType, aWindow, folder, key, headers, autoAction); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGMDNGENERATOR(_to) \
  NS_IMETHOD Process(EDisposeType eType, nsIMsgWindow *aWindow, nsIMsgFolder *folder, nsMsgKey key, nsIMimeHeaders *headers, PRBool autoAction) { return !_to ? NS_ERROR_NULL_POINTER : _to->Process(eType, aWindow, folder, key, headers, autoAction); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgMdnGenerator : public nsIMsgMdnGenerator
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGMDNGENERATOR

  nsMsgMdnGenerator();

private:
  ~nsMsgMdnGenerator();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgMdnGenerator, nsIMsgMdnGenerator)

nsMsgMdnGenerator::nsMsgMdnGenerator()
{
  /* member initializers and constructor code */
}

nsMsgMdnGenerator::~nsMsgMdnGenerator()
{
  /* destructor code */
}

/* void process (in EDisposeType eType, in nsIMsgWindow aWindow, in nsIMsgFolder folder, in nsMsgKey key, in nsIMimeHeaders headers, in boolean autoAction); */
NS_IMETHODIMP nsMsgMdnGenerator::Process(EDisposeType eType, nsIMsgWindow *aWindow, nsIMsgFolder *folder, nsMsgKey key, nsIMimeHeaders *headers, PRBool autoAction)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgMdnGenerator_h__ */
