/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgFolderCompactor.idl
 */

#ifndef __gen_nsIMsgFolderCompactor_h__
#define __gen_nsIMsgFolderCompactor_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsISupportsArray_h__
#include "nsISupportsArray.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgFolder; /* forward declaration */

class nsIMsgDatabase; /* forward declaration */

class nsIFileSpec; /* forward declaration */

class nsIMsgWindow; /* forward declaration */


/* starting interface:    nsIMsgFolderCompactor */
#define NS_IMSGFOLDERCOMPACTOR_IID_STR "2af7d7a2-e5b6-11d4-a5b7-0060b0fc04b7"

#define NS_IMSGFOLDERCOMPACTOR_IID \
  {0x2af7d7a2, 0xe5b6, 0x11d4, \
    { 0xa5, 0xb7, 0x00, 0x60, 0xb0, 0xfc, 0x04, 0xb7 }}

class NS_NO_VTABLE nsIMsgFolderCompactor : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGFOLDERCOMPACTOR_IID)

  /* void compact (in nsIMsgFolder aFolder, in boolean aOfflineStore, in nsIMsgWindow aMsgWindow); */
  NS_IMETHOD Compact(nsIMsgFolder *aFolder, PRBool aOfflineStore, nsIMsgWindow *aMsgWindow) = 0;

  /* void compactAll (in nsISupportsArray aArrayOfFoldersToCompact, in nsIMsgWindow aMsgWindow, in boolean compactOfflineAlso, in nsISupportsArray aOfflineFolderArray); */
  NS_IMETHOD CompactAll(nsISupportsArray *aArrayOfFoldersToCompact, nsIMsgWindow *aMsgWindow, PRBool compactOfflineAlso, nsISupportsArray *aOfflineFolderArray) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFOLDERCOMPACTOR \
  NS_IMETHOD Compact(nsIMsgFolder *aFolder, PRBool aOfflineStore, nsIMsgWindow *aMsgWindow); \
  NS_IMETHOD CompactAll(nsISupportsArray *aArrayOfFoldersToCompact, nsIMsgWindow *aMsgWindow, PRBool compactOfflineAlso, nsISupportsArray *aOfflineFolderArray); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFOLDERCOMPACTOR(_to) \
  NS_IMETHOD Compact(nsIMsgFolder *aFolder, PRBool aOfflineStore, nsIMsgWindow *aMsgWindow) { return _to Compact(aFolder, aOfflineStore, aMsgWindow); } \
  NS_IMETHOD CompactAll(nsISupportsArray *aArrayOfFoldersToCompact, nsIMsgWindow *aMsgWindow, PRBool compactOfflineAlso, nsISupportsArray *aOfflineFolderArray) { return _to CompactAll(aArrayOfFoldersToCompact, aMsgWindow, compactOfflineAlso, aOfflineFolderArray); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFOLDERCOMPACTOR(_to) \
  NS_IMETHOD Compact(nsIMsgFolder *aFolder, PRBool aOfflineStore, nsIMsgWindow *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->Compact(aFolder, aOfflineStore, aMsgWindow); } \
  NS_IMETHOD CompactAll(nsISupportsArray *aArrayOfFoldersToCompact, nsIMsgWindow *aMsgWindow, PRBool compactOfflineAlso, nsISupportsArray *aOfflineFolderArray) { return !_to ? NS_ERROR_NULL_POINTER : _to->CompactAll(aArrayOfFoldersToCompact, aMsgWindow, compactOfflineAlso, aOfflineFolderArray); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFolderCompactor : public nsIMsgFolderCompactor
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFOLDERCOMPACTOR

  nsMsgFolderCompactor();

private:
  ~nsMsgFolderCompactor();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFolderCompactor, nsIMsgFolderCompactor)

nsMsgFolderCompactor::nsMsgFolderCompactor()
{
  /* member initializers and constructor code */
}

nsMsgFolderCompactor::~nsMsgFolderCompactor()
{
  /* destructor code */
}

/* void compact (in nsIMsgFolder aFolder, in boolean aOfflineStore, in nsIMsgWindow aMsgWindow); */
NS_IMETHODIMP nsMsgFolderCompactor::Compact(nsIMsgFolder *aFolder, PRBool aOfflineStore, nsIMsgWindow *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void compactAll (in nsISupportsArray aArrayOfFoldersToCompact, in nsIMsgWindow aMsgWindow, in boolean compactOfflineAlso, in nsISupportsArray aOfflineFolderArray); */
NS_IMETHODIMP nsMsgFolderCompactor::CompactAll(nsISupportsArray *aArrayOfFoldersToCompact, nsIMsgWindow *aMsgWindow, PRBool compactOfflineAlso, nsISupportsArray *aOfflineFolderArray)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFolderCompactor_h__ */
