/* List of defines generated by configure. Included with preprocessor flag,
 * -include, to avoid long list of -D defines on the compile command-line.
 * Do not edit.
 */

#ifndef _MOZILLA_CONFIG_H_
#define _MOZILLA_CONFIG_H_

#define D_INO d_ino
#define FUNCPROTO 15
#define HAVE_64BIT_OS 1
#define HAVE_DIRENT_H 1
#define HAVE_FCHMOD 1
#define HAVE_FLOCKFILE 1
#define HAVE_GETOPT_H 1
#define HAVE_GNU_GET_LIBC_VERSION 1
#define HAVE_GNU_LIBC_VERSION_H 1
#define HAVE_I18N_LC_MESSAGES 1
#define HAVE_INT16_T 1
#define HAVE_INT32_T 1
#define HAVE_INT64_T 1
#define HAVE_LANGINFO_CODESET 1
#define HAVE_LCHOWN 1
#define HAVE_LIBDL 1
#define HAVE_LIBM 1
#define HAVE_LOCALTIME_R 1
#define HAVE_LSTAT64 1
#define HAVE_MALLOC_H 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMORY_H 1
#define HAVE_MMINTRIN_H 1
#define HAVE_NL_TYPES_H 1
#define HAVE_RANDOM 1
#define HAVE_RES_NINIT 1
#define HAVE_RINT 1
#define HAVE_SIGINFO_T 1
#define HAVE_SNPRINTF 1
#define HAVE_STAT64 1
#define HAVE_STRERROR 1
#define HAVE_STRTOK_R 1
#define HAVE_ST_BLKSIZE 1
#define HAVE_SYS_BITYPES_H 1
#define HAVE_SYS_CDEFS_H 1
#define HAVE_SYS_STATFS_H 1
#define HAVE_SYS_STATVFS_H 1
#define HAVE_UINT 1
#define HAVE_UNAME_DOMAINNAME_FIELD 1
#define HAVE_UNISTD_H 1
#define HAVE_VA_COPY 1
#define HAVE_VA_LIST_AS_ARRAY 1
#define HAVE_VISIBILITY_ATTRIBUTE 1
#define HAVE_VISIBILITY_HIDDEN_ATTRIBUTE 1
#define HAVE_X11_XKBLIB_H 1
#define HAVE_XSHM 1
#define HAVE___CXA_DEMANGLE 1
#define IBMBIDI 1
#define JS_THREADSAFE 1
#define MOZILLA_1_8_BRANCH 1
#define MOZILLA_LOCALE_VERSION "1.8.1"
#define MOZILLA_REGION_VERSION "1.8.1"
#define MOZILLA_SKIN_VERSION "1.8"
#define MOZILLA_VERSION "1.8.1.14"
#define MOZILLA_VERSION_U 1.8.1.14
#define MOZ_BUILD_APP mail
#define MOZ_DEFAULT_MOZILLA_FIVE_HOME "/usr/lib64/thunderbird-2.0.0.14"
#define MOZ_DEFAULT_TOOLKIT "gtk2"
#define MOZ_DISTRIBUTION_ID "org.mozilla"
#define MOZ_DLL_SUFFIX ".so"
#define MOZ_ENABLE_XFT 1
#define MOZ_ENABLE_XINERAMA 1
#define MOZ_ENABLE_XREMOTE 1
#define MOZ_FEEDS 1
#define MOZ_JSLOADER 1
#define MOZ_MORK 1
#define MOZ_PROFILELOCKING 1
#define MOZ_SAFE_BROWSING 1
#define MOZ_STATIC_MAIL_BUILD 1
#define MOZ_STORAGE 1
#define MOZ_THUNDERBIRD 1
#define MOZ_UPDATE_CHANNEL default
#define MOZ_URL_CLASSIFIER 1
#define MOZ_USER_DIR ".thunderbird"
#define MOZ_VIEW_SOURCE 1
#define MOZ_WIDGET_GTK2 1
#define MOZ_X11 1
#define MOZ_XPINSTALL 1
#define MOZ_XTF 1
#define MOZ_XUL 1
#define MOZ_XUL_APP 1
#define NS_DISABLE_LOGGING 1
#define NS_PRINTING 1
#define NS_PRINT_PREVIEW 1
#define STDC_HEADERS 1
#define UNIX_ASYNC_DNS 1
#define VA_COPY va_copy
#define XP_UNIX 1
#define _REENTRANT 1

#endif /* _MOZILLA_CONFIG_H_ */

