/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgSearchTerm.idl
 */

#ifndef __gen_nsIMsgSearchTerm_h__
#define __gen_nsIMsgSearchTerm_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsMsgSearchCore_h__
#include "nsMsgSearchCore.h"
#endif

#ifndef __gen_nsIMsgSearchValue_h__
#include "nsIMsgSearchValue.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgDBHdr; /* forward declaration */

class nsIMsgDatabase; /* forward declaration */

class nsIMsgSearchScopeTerm; /* forward declaration */


/* starting interface:    nsIMsgSearchTerm */
#define NS_IMSGSEARCHTERM_IID_STR "cde583fe-9add-4adb-9e1a-9cfe050d8a26"

#define NS_IMSGSEARCHTERM_IID \
  {0xcde583fe, 0x9add, 0x4adb, \
    { 0x9e, 0x1a, 0x9c, 0xfe, 0x05, 0x0d, 0x8a, 0x26 }}

class NS_NO_VTABLE nsIMsgSearchTerm : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGSEARCHTERM_IID)

  /* attribute nsMsgSearchAttribValue attrib; */
  NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib) = 0;
  NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib) = 0;

  /* attribute nsMsgSearchOpValue op; */
  NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp) = 0;
  NS_IMETHOD SetOp(nsMsgSearchOpValue aOp) = 0;

  /* attribute nsIMsgSearchValue value; */
  NS_IMETHOD GetValue(nsIMsgSearchValue * *aValue) = 0;
  NS_IMETHOD SetValue(nsIMsgSearchValue * aValue) = 0;

  /* attribute boolean booleanAnd; */
  NS_IMETHOD GetBooleanAnd(PRBool *aBooleanAnd) = 0;
  NS_IMETHOD SetBooleanAnd(PRBool aBooleanAnd) = 0;

  /* attribute string arbitraryHeader; */
  NS_IMETHOD GetArbitraryHeader(char * *aArbitraryHeader) = 0;
  NS_IMETHOD SetArbitraryHeader(const char * aArbitraryHeader) = 0;

  /* attribute boolean beginsGrouping; */
  NS_IMETHOD GetBeginsGrouping(PRBool *aBeginsGrouping) = 0;
  NS_IMETHOD SetBeginsGrouping(PRBool aBeginsGrouping) = 0;

  /* attribute boolean endsGrouping; */
  NS_IMETHOD GetEndsGrouping(PRBool *aEndsGrouping) = 0;
  NS_IMETHOD SetEndsGrouping(PRBool aEndsGrouping) = 0;

  /* boolean matchRfc822String (in string aString, in string charset, in boolean charsetOverride); */
  NS_IMETHOD MatchRfc822String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval) = 0;

  /* boolean matchRfc2047String (in string aString, in string charset, in boolean charsetOverride); */
  NS_IMETHOD MatchRfc2047String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval) = 0;

  /* boolean matchDate (in PRTime aTime); */
  NS_IMETHOD MatchDate(PRTime aTime, PRBool *_retval) = 0;

  /* boolean matchStatus (in unsigned long aStatus); */
  NS_IMETHOD MatchStatus(PRUint32 aStatus, PRBool *_retval) = 0;

  /* boolean matchPriority (in nsMsgPriorityValue priority); */
  NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, PRBool *_retval) = 0;

  /* boolean matchAge (in PRTime days); */
  NS_IMETHOD MatchAge(PRTime days, PRBool *_retval) = 0;

  /* boolean matchSize (in unsigned long size); */
  NS_IMETHOD MatchSize(PRUint32 size, PRBool *_retval) = 0;

  /* boolean matchLabel (in nsMsgLabelValue aLabelValue); */
  NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, PRBool *_retval) = 0;

  /* boolean matchJunkStatus (in string aJunkScore); */
  NS_IMETHOD MatchJunkStatus(const char *aJunkScore, PRBool *_retval) = 0;

  /* boolean matchBody (in nsIMsgSearchScopeTerm scopeTerm, in unsigned long offset, in unsigned long length, in string charset, in nsIMsgDBHdr msg, in nsIMsgDatabase db); */
  NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *scopeTerm, PRUint32 offset, PRUint32 length, const char *charset, nsIMsgDBHdr *msg, nsIMsgDatabase *db, PRBool *_retval) = 0;

  /* [noscript] boolean matchArbitraryHeader (in nsIMsgSearchScopeTerm scopeTerm, in unsigned long offset, in unsigned long length, in string charset, in boolean charsetOverride, in nsIMsgDBHdr msg, in nsIMsgDatabase db, in string headers, in unsigned long headerLength, in boolean forFilters); */
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *scopeTerm, PRUint32 offset, PRUint32 length, const char *charset, PRBool charsetOverride, nsIMsgDBHdr *msg, nsIMsgDatabase *db, const char *headers, PRUint32 headerLength, PRBool forFilters, PRBool *_retval) = 0;

  /* readonly attribute boolean matchAllBeforeDeciding; */
  NS_IMETHOD GetMatchAllBeforeDeciding(PRBool *aMatchAllBeforeDeciding) = 0;

  /* readonly attribute ACString termAsString; */
  NS_IMETHOD GetTermAsString(nsACString & aTermAsString) = 0;

  /* boolean matchKeyword (in string keyword); */
  NS_IMETHOD MatchKeyword(const char *keyword, PRBool *_retval) = 0;

  /* attribute boolean matchAll; */
  NS_IMETHOD GetMatchAll(PRBool *aMatchAll) = 0;
  NS_IMETHOD SetMatchAll(PRBool aMatchAll) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSEARCHTERM \
  NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib); \
  NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib); \
  NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp); \
  NS_IMETHOD SetOp(nsMsgSearchOpValue aOp); \
  NS_IMETHOD GetValue(nsIMsgSearchValue * *aValue); \
  NS_IMETHOD SetValue(nsIMsgSearchValue * aValue); \
  NS_IMETHOD GetBooleanAnd(PRBool *aBooleanAnd); \
  NS_IMETHOD SetBooleanAnd(PRBool aBooleanAnd); \
  NS_IMETHOD GetArbitraryHeader(char * *aArbitraryHeader); \
  NS_IMETHOD SetArbitraryHeader(const char * aArbitraryHeader); \
  NS_IMETHOD GetBeginsGrouping(PRBool *aBeginsGrouping); \
  NS_IMETHOD SetBeginsGrouping(PRBool aBeginsGrouping); \
  NS_IMETHOD GetEndsGrouping(PRBool *aEndsGrouping); \
  NS_IMETHOD SetEndsGrouping(PRBool aEndsGrouping); \
  NS_IMETHOD MatchRfc822String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval); \
  NS_IMETHOD MatchRfc2047String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval); \
  NS_IMETHOD MatchDate(PRTime aTime, PRBool *_retval); \
  NS_IMETHOD MatchStatus(PRUint32 aStatus, PRBool *_retval); \
  NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, PRBool *_retval); \
  NS_IMETHOD MatchAge(PRTime days, PRBool *_retval); \
  NS_IMETHOD MatchSize(PRUint32 size, PRBool *_retval); \
  NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, PRBool *_retval); \
  NS_IMETHOD MatchJunkStatus(const char *aJunkScore, PRBool *_retval); \
  NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *scopeTerm, PRUint32 offset, PRUint32 length, const char *charset, nsIMsgDBHdr *msg, nsIMsgDatabase *db, PRBool *_retval); \
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *scopeTerm, PRUint32 offset, PRUint32 length, const char *charset, PRBool charsetOverride, nsIMsgDBHdr *msg, nsIMsgDatabase *db, const char *headers, PRUint32 headerLength, PRBool forFilters, PRBool *_retval); \
  NS_IMETHOD GetMatchAllBeforeDeciding(PRBool *aMatchAllBeforeDeciding); \
  NS_IMETHOD GetTermAsString(nsACString & aTermAsString); \
  NS_IMETHOD MatchKeyword(const char *keyword, PRBool *_retval); \
  NS_IMETHOD GetMatchAll(PRBool *aMatchAll); \
  NS_IMETHOD SetMatchAll(PRBool aMatchAll); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSEARCHTERM(_to) \
  NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib) { return _to GetAttrib(aAttrib); } \
  NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib) { return _to SetAttrib(aAttrib); } \
  NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp) { return _to GetOp(aOp); } \
  NS_IMETHOD SetOp(nsMsgSearchOpValue aOp) { return _to SetOp(aOp); } \
  NS_IMETHOD GetValue(nsIMsgSearchValue * *aValue) { return _to GetValue(aValue); } \
  NS_IMETHOD SetValue(nsIMsgSearchValue * aValue) { return _to SetValue(aValue); } \
  NS_IMETHOD GetBooleanAnd(PRBool *aBooleanAnd) { return _to GetBooleanAnd(aBooleanAnd); } \
  NS_IMETHOD SetBooleanAnd(PRBool aBooleanAnd) { return _to SetBooleanAnd(aBooleanAnd); } \
  NS_IMETHOD GetArbitraryHeader(char * *aArbitraryHeader) { return _to GetArbitraryHeader(aArbitraryHeader); } \
  NS_IMETHOD SetArbitraryHeader(const char * aArbitraryHeader) { return _to SetArbitraryHeader(aArbitraryHeader); } \
  NS_IMETHOD GetBeginsGrouping(PRBool *aBeginsGrouping) { return _to GetBeginsGrouping(aBeginsGrouping); } \
  NS_IMETHOD SetBeginsGrouping(PRBool aBeginsGrouping) { return _to SetBeginsGrouping(aBeginsGrouping); } \
  NS_IMETHOD GetEndsGrouping(PRBool *aEndsGrouping) { return _to GetEndsGrouping(aEndsGrouping); } \
  NS_IMETHOD SetEndsGrouping(PRBool aEndsGrouping) { return _to SetEndsGrouping(aEndsGrouping); } \
  NS_IMETHOD MatchRfc822String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval) { return _to MatchRfc822String(aString, charset, charsetOverride, _retval); } \
  NS_IMETHOD MatchRfc2047String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval) { return _to MatchRfc2047String(aString, charset, charsetOverride, _retval); } \
  NS_IMETHOD MatchDate(PRTime aTime, PRBool *_retval) { return _to MatchDate(aTime, _retval); } \
  NS_IMETHOD MatchStatus(PRUint32 aStatus, PRBool *_retval) { return _to MatchStatus(aStatus, _retval); } \
  NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, PRBool *_retval) { return _to MatchPriority(priority, _retval); } \
  NS_IMETHOD MatchAge(PRTime days, PRBool *_retval) { return _to MatchAge(days, _retval); } \
  NS_IMETHOD MatchSize(PRUint32 size, PRBool *_retval) { return _to MatchSize(size, _retval); } \
  NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, PRBool *_retval) { return _to MatchLabel(aLabelValue, _retval); } \
  NS_IMETHOD MatchJunkStatus(const char *aJunkScore, PRBool *_retval) { return _to MatchJunkStatus(aJunkScore, _retval); } \
  NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *scopeTerm, PRUint32 offset, PRUint32 length, const char *charset, nsIMsgDBHdr *msg, nsIMsgDatabase *db, PRBool *_retval) { return _to MatchBody(scopeTerm, offset, length, charset, msg, db, _retval); } \
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *scopeTerm, PRUint32 offset, PRUint32 length, const char *charset, PRBool charsetOverride, nsIMsgDBHdr *msg, nsIMsgDatabase *db, const char *headers, PRUint32 headerLength, PRBool forFilters, PRBool *_retval) { return _to MatchArbitraryHeader(scopeTerm, offset, length, charset, charsetOverride, msg, db, headers, headerLength, forFilters, _retval); } \
  NS_IMETHOD GetMatchAllBeforeDeciding(PRBool *aMatchAllBeforeDeciding) { return _to GetMatchAllBeforeDeciding(aMatchAllBeforeDeciding); } \
  NS_IMETHOD GetTermAsString(nsACString & aTermAsString) { return _to GetTermAsString(aTermAsString); } \
  NS_IMETHOD MatchKeyword(const char *keyword, PRBool *_retval) { return _to MatchKeyword(keyword, _retval); } \
  NS_IMETHOD GetMatchAll(PRBool *aMatchAll) { return _to GetMatchAll(aMatchAll); } \
  NS_IMETHOD SetMatchAll(PRBool aMatchAll) { return _to SetMatchAll(aMatchAll); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSEARCHTERM(_to) \
  NS_IMETHOD GetAttrib(nsMsgSearchAttribValue *aAttrib) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetAttrib(aAttrib); } \
  NS_IMETHOD SetAttrib(nsMsgSearchAttribValue aAttrib) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetAttrib(aAttrib); } \
  NS_IMETHOD GetOp(nsMsgSearchOpValue *aOp) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOp(aOp); } \
  NS_IMETHOD SetOp(nsMsgSearchOpValue aOp) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOp(aOp); } \
  NS_IMETHOD GetValue(nsIMsgSearchValue * *aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetValue(aValue); } \
  NS_IMETHOD SetValue(nsIMsgSearchValue * aValue) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetValue(aValue); } \
  NS_IMETHOD GetBooleanAnd(PRBool *aBooleanAnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBooleanAnd(aBooleanAnd); } \
  NS_IMETHOD SetBooleanAnd(PRBool aBooleanAnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBooleanAnd(aBooleanAnd); } \
  NS_IMETHOD GetArbitraryHeader(char * *aArbitraryHeader) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetArbitraryHeader(aArbitraryHeader); } \
  NS_IMETHOD SetArbitraryHeader(const char * aArbitraryHeader) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetArbitraryHeader(aArbitraryHeader); } \
  NS_IMETHOD GetBeginsGrouping(PRBool *aBeginsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBeginsGrouping(aBeginsGrouping); } \
  NS_IMETHOD SetBeginsGrouping(PRBool aBeginsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBeginsGrouping(aBeginsGrouping); } \
  NS_IMETHOD GetEndsGrouping(PRBool *aEndsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEndsGrouping(aEndsGrouping); } \
  NS_IMETHOD SetEndsGrouping(PRBool aEndsGrouping) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetEndsGrouping(aEndsGrouping); } \
  NS_IMETHOD MatchRfc822String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchRfc822String(aString, charset, charsetOverride, _retval); } \
  NS_IMETHOD MatchRfc2047String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchRfc2047String(aString, charset, charsetOverride, _retval); } \
  NS_IMETHOD MatchDate(PRTime aTime, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchDate(aTime, _retval); } \
  NS_IMETHOD MatchStatus(PRUint32 aStatus, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchStatus(aStatus, _retval); } \
  NS_IMETHOD MatchPriority(nsMsgPriorityValue priority, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchPriority(priority, _retval); } \
  NS_IMETHOD MatchAge(PRTime days, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchAge(days, _retval); } \
  NS_IMETHOD MatchSize(PRUint32 size, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchSize(size, _retval); } \
  NS_IMETHOD MatchLabel(nsMsgLabelValue aLabelValue, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchLabel(aLabelValue, _retval); } \
  NS_IMETHOD MatchJunkStatus(const char *aJunkScore, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchJunkStatus(aJunkScore, _retval); } \
  NS_IMETHOD MatchBody(nsIMsgSearchScopeTerm *scopeTerm, PRUint32 offset, PRUint32 length, const char *charset, nsIMsgDBHdr *msg, nsIMsgDatabase *db, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchBody(scopeTerm, offset, length, charset, msg, db, _retval); } \
  NS_IMETHOD MatchArbitraryHeader(nsIMsgSearchScopeTerm *scopeTerm, PRUint32 offset, PRUint32 length, const char *charset, PRBool charsetOverride, nsIMsgDBHdr *msg, nsIMsgDatabase *db, const char *headers, PRUint32 headerLength, PRBool forFilters, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchArbitraryHeader(scopeTerm, offset, length, charset, charsetOverride, msg, db, headers, headerLength, forFilters, _retval); } \
  NS_IMETHOD GetMatchAllBeforeDeciding(PRBool *aMatchAllBeforeDeciding) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMatchAllBeforeDeciding(aMatchAllBeforeDeciding); } \
  NS_IMETHOD GetTermAsString(nsACString & aTermAsString) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTermAsString(aTermAsString); } \
  NS_IMETHOD MatchKeyword(const char *keyword, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->MatchKeyword(keyword, _retval); } \
  NS_IMETHOD GetMatchAll(PRBool *aMatchAll) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMatchAll(aMatchAll); } \
  NS_IMETHOD SetMatchAll(PRBool aMatchAll) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMatchAll(aMatchAll); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSearchTerm : public nsIMsgSearchTerm
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSEARCHTERM

  nsMsgSearchTerm();

private:
  ~nsMsgSearchTerm();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSearchTerm, nsIMsgSearchTerm)

nsMsgSearchTerm::nsMsgSearchTerm()
{
  /* member initializers and constructor code */
}

nsMsgSearchTerm::~nsMsgSearchTerm()
{
  /* destructor code */
}

/* attribute nsMsgSearchAttribValue attrib; */
NS_IMETHODIMP nsMsgSearchTerm::GetAttrib(nsMsgSearchAttribValue *aAttrib)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetAttrib(nsMsgSearchAttribValue aAttrib)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsMsgSearchOpValue op; */
NS_IMETHODIMP nsMsgSearchTerm::GetOp(nsMsgSearchOpValue *aOp)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetOp(nsMsgSearchOpValue aOp)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgSearchValue value; */
NS_IMETHODIMP nsMsgSearchTerm::GetValue(nsIMsgSearchValue * *aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetValue(nsIMsgSearchValue * aValue)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean booleanAnd; */
NS_IMETHODIMP nsMsgSearchTerm::GetBooleanAnd(PRBool *aBooleanAnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetBooleanAnd(PRBool aBooleanAnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string arbitraryHeader; */
NS_IMETHODIMP nsMsgSearchTerm::GetArbitraryHeader(char * *aArbitraryHeader)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetArbitraryHeader(const char * aArbitraryHeader)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean beginsGrouping; */
NS_IMETHODIMP nsMsgSearchTerm::GetBeginsGrouping(PRBool *aBeginsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetBeginsGrouping(PRBool aBeginsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean endsGrouping; */
NS_IMETHODIMP nsMsgSearchTerm::GetEndsGrouping(PRBool *aEndsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetEndsGrouping(PRBool aEndsGrouping)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchRfc822String (in string aString, in string charset, in boolean charsetOverride); */
NS_IMETHODIMP nsMsgSearchTerm::MatchRfc822String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchRfc2047String (in string aString, in string charset, in boolean charsetOverride); */
NS_IMETHODIMP nsMsgSearchTerm::MatchRfc2047String(const char *aString, const char *charset, PRBool charsetOverride, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchDate (in PRTime aTime); */
NS_IMETHODIMP nsMsgSearchTerm::MatchDate(PRTime aTime, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchStatus (in unsigned long aStatus); */
NS_IMETHODIMP nsMsgSearchTerm::MatchStatus(PRUint32 aStatus, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchPriority (in nsMsgPriorityValue priority); */
NS_IMETHODIMP nsMsgSearchTerm::MatchPriority(nsMsgPriorityValue priority, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchAge (in PRTime days); */
NS_IMETHODIMP nsMsgSearchTerm::MatchAge(PRTime days, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchSize (in unsigned long size); */
NS_IMETHODIMP nsMsgSearchTerm::MatchSize(PRUint32 size, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchLabel (in nsMsgLabelValue aLabelValue); */
NS_IMETHODIMP nsMsgSearchTerm::MatchLabel(nsMsgLabelValue aLabelValue, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchJunkStatus (in string aJunkScore); */
NS_IMETHODIMP nsMsgSearchTerm::MatchJunkStatus(const char *aJunkScore, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchBody (in nsIMsgSearchScopeTerm scopeTerm, in unsigned long offset, in unsigned long length, in string charset, in nsIMsgDBHdr msg, in nsIMsgDatabase db); */
NS_IMETHODIMP nsMsgSearchTerm::MatchBody(nsIMsgSearchScopeTerm *scopeTerm, PRUint32 offset, PRUint32 length, const char *charset, nsIMsgDBHdr *msg, nsIMsgDatabase *db, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] boolean matchArbitraryHeader (in nsIMsgSearchScopeTerm scopeTerm, in unsigned long offset, in unsigned long length, in string charset, in boolean charsetOverride, in nsIMsgDBHdr msg, in nsIMsgDatabase db, in string headers, in unsigned long headerLength, in boolean forFilters); */
NS_IMETHODIMP nsMsgSearchTerm::MatchArbitraryHeader(nsIMsgSearchScopeTerm *scopeTerm, PRUint32 offset, PRUint32 length, const char *charset, PRBool charsetOverride, nsIMsgDBHdr *msg, nsIMsgDatabase *db, const char *headers, PRUint32 headerLength, PRBool forFilters, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean matchAllBeforeDeciding; */
NS_IMETHODIMP nsMsgSearchTerm::GetMatchAllBeforeDeciding(PRBool *aMatchAllBeforeDeciding)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute ACString termAsString; */
NS_IMETHODIMP nsMsgSearchTerm::GetTermAsString(nsACString & aTermAsString)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean matchKeyword (in string keyword); */
NS_IMETHODIMP nsMsgSearchTerm::MatchKeyword(const char *keyword, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean matchAll; */
NS_IMETHODIMP nsMsgSearchTerm::GetMatchAll(PRBool *aMatchAll)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSearchTerm::SetMatchAll(PRBool aMatchAll)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSearchTerm_h__ */
