/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIComm4xProfile.idl
 */

#ifndef __gen_nsIComm4xProfile_h__
#define __gen_nsIComm4xProfile_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsILocalFile_h__
#include "nsILocalFile.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIComm4xProfile */
#define NS_ICOMM4XPROFILE_IID_STR "c66c1060-2bdc-11d6-92a0-0010a4b26cda"

#define NS_ICOMM4XPROFILE_IID \
  {0xc66c1060, 0x2bdc, 0x11d6, \
    { 0x92, 0xa0, 0x00, 0x10, 0xa4, 0xb2, 0x6c, 0xda }}

/**
 * This interface provides support for getting 4.x profile information
 * This interface can be used to get the existing 4.x profiles
 * and for getting the mail directory for the profile.
 * 
 */
class NS_NO_VTABLE nsIComm4xProfile : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ICOMM4XPROFILE_IID)

  /**
    *  Parses the 4.x registry file and returns a list of profiles. 
    */
  /* void getProfileList (out unsigned long length, [array, size_is (length), retval] out wstring selectList); */
  NS_IMETHOD GetProfileList(PRUint32 *length, PRUnichar ***selectList) = 0;

  /**
    *  Searches the preferences file of the given profile for the pref mail.directory
    *  If the pref does not exist it, returns the default value.
    *  @param profileName  name of the profile in the profiles array 
    *  @return             The path to the mail directory for the profile with the name profileName
    *   
    */
  /* wstring getMailDir (in wstring profileName); */
  NS_IMETHOD GetMailDir(const PRUnichar *profileName, PRUnichar **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSICOMM4XPROFILE \
  NS_IMETHOD GetProfileList(PRUint32 *length, PRUnichar ***selectList); \
  NS_IMETHOD GetMailDir(const PRUnichar *profileName, PRUnichar **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSICOMM4XPROFILE(_to) \
  NS_IMETHOD GetProfileList(PRUint32 *length, PRUnichar ***selectList) { return _to GetProfileList(length, selectList); } \
  NS_IMETHOD GetMailDir(const PRUnichar *profileName, PRUnichar **_retval) { return _to GetMailDir(profileName, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSICOMM4XPROFILE(_to) \
  NS_IMETHOD GetProfileList(PRUint32 *length, PRUnichar ***selectList) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetProfileList(length, selectList); } \
  NS_IMETHOD GetMailDir(const PRUnichar *profileName, PRUnichar **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMailDir(profileName, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsComm4xProfile : public nsIComm4xProfile
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSICOMM4XPROFILE

  nsComm4xProfile();

private:
  ~nsComm4xProfile();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsComm4xProfile, nsIComm4xProfile)

nsComm4xProfile::nsComm4xProfile()
{
  /* member initializers and constructor code */
}

nsComm4xProfile::~nsComm4xProfile()
{
  /* destructor code */
}

/* void getProfileList (out unsigned long length, [array, size_is (length), retval] out wstring selectList); */
NS_IMETHODIMP nsComm4xProfile::GetProfileList(PRUint32 *length, PRUnichar ***selectList)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring getMailDir (in wstring profileName); */
NS_IMETHODIMP nsComm4xProfile::GetMailDir(const PRUnichar *profileName, PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIComm4xProfile_h__ */
