/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgSearchValidityManager.idl
 */

#ifndef __gen_nsIMsgSearchValidityManager_h__
#define __gen_nsIMsgSearchValidityManager_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgSearchValidityTable_h__
#include "nsIMsgSearchValidityTable.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
typedef PRInt32 nsMsgSearchValidityScope;


/* starting interface:    nsIMsgSearchValidityManager */
#define NS_IMSGSEARCHVALIDITYMANAGER_IID_STR "98651499-6820-42e4-a2d7-e75277e01f7d"

#define NS_IMSGSEARCHVALIDITYMANAGER_IID \
  {0x98651499, 0x6820, 0x42e4, \
    { 0xa2, 0xd7, 0xe7, 0x52, 0x77, 0xe0, 0x1f, 0x7d }}

class NS_NO_VTABLE nsIMsgSearchValidityManager : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGSEARCHVALIDITYMANAGER_IID)

  /* nsIMsgSearchValidityTable getTable (in nsMsgSearchValidityScope scope); */
  NS_IMETHOD GetTable(nsMsgSearchValidityScope scope, nsIMsgSearchValidityTable **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSEARCHVALIDITYMANAGER \
  NS_IMETHOD GetTable(nsMsgSearchValidityScope scope, nsIMsgSearchValidityTable **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSEARCHVALIDITYMANAGER(_to) \
  NS_IMETHOD GetTable(nsMsgSearchValidityScope scope, nsIMsgSearchValidityTable **_retval) { return _to GetTable(scope, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSEARCHVALIDITYMANAGER(_to) \
  NS_IMETHOD GetTable(nsMsgSearchValidityScope scope, nsIMsgSearchValidityTable **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTable(scope, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSearchValidityManager : public nsIMsgSearchValidityManager
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSEARCHVALIDITYMANAGER

  nsMsgSearchValidityManager();

private:
  ~nsMsgSearchValidityManager();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSearchValidityManager, nsIMsgSearchValidityManager)

nsMsgSearchValidityManager::nsMsgSearchValidityManager()
{
  /* member initializers and constructor code */
}

nsMsgSearchValidityManager::~nsMsgSearchValidityManager()
{
  /* destructor code */
}

/* nsIMsgSearchValidityTable getTable (in nsMsgSearchValidityScope scope); */
NS_IMETHODIMP nsMsgSearchValidityManager::GetTable(nsMsgSearchValidityScope scope, nsIMsgSearchValidityTable **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSearchValidityManager_h__ */
