/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgSignature.idl
 */

#ifndef __gen_nsIMsgSignature_h__
#define __gen_nsIMsgSignature_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgSignature */
#define NS_IMSGSIGNATURE_IID_STR "7e1531b0-e3df-11d2-b7fc-00805f05ffa5"

#define NS_IMSGSIGNATURE_IID \
  {0x7e1531b0, 0xe3df, 0x11d2, \
    { 0xb7, 0xfc, 0x00, 0x80, 0x5f, 0x05, 0xff, 0xa5 }}

class NS_NO_VTABLE nsIMsgSignature : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGSIGNATURE_IID)

  /* attribute string signatureName; */
  NS_IMETHOD GetSignatureName(char * *aSignatureName) = 0;
  NS_IMETHOD SetSignatureName(const char * aSignatureName) = 0;

  /* attribute string signature; */
  NS_IMETHOD GetSignature(char * *aSignature) = 0;
  NS_IMETHOD SetSignature(const char * aSignature) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSIGNATURE \
  NS_IMETHOD GetSignatureName(char * *aSignatureName); \
  NS_IMETHOD SetSignatureName(const char * aSignatureName); \
  NS_IMETHOD GetSignature(char * *aSignature); \
  NS_IMETHOD SetSignature(const char * aSignature); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSIGNATURE(_to) \
  NS_IMETHOD GetSignatureName(char * *aSignatureName) { return _to GetSignatureName(aSignatureName); } \
  NS_IMETHOD SetSignatureName(const char * aSignatureName) { return _to SetSignatureName(aSignatureName); } \
  NS_IMETHOD GetSignature(char * *aSignature) { return _to GetSignature(aSignature); } \
  NS_IMETHOD SetSignature(const char * aSignature) { return _to SetSignature(aSignature); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSIGNATURE(_to) \
  NS_IMETHOD GetSignatureName(char * *aSignatureName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSignatureName(aSignatureName); } \
  NS_IMETHOD SetSignatureName(const char * aSignatureName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSignatureName(aSignatureName); } \
  NS_IMETHOD GetSignature(char * *aSignature) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSignature(aSignature); } \
  NS_IMETHOD SetSignature(const char * aSignature) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSignature(aSignature); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSignature : public nsIMsgSignature
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSIGNATURE

  nsMsgSignature();

private:
  ~nsMsgSignature();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSignature, nsIMsgSignature)

nsMsgSignature::nsMsgSignature()
{
  /* member initializers and constructor code */
}

nsMsgSignature::~nsMsgSignature()
{
  /* destructor code */
}

/* attribute string signatureName; */
NS_IMETHODIMP nsMsgSignature::GetSignatureName(char * *aSignatureName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSignature::SetSignatureName(const char * aSignatureName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string signature; */
NS_IMETHODIMP nsMsgSignature::GetSignature(char * *aSignature)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSignature::SetSignature(const char * aSignature)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSignature_h__ */
