/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgSendLater.idl
 */

#ifndef __gen_nsIMsgSendLater_h__
#define __gen_nsIMsgSendLater_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsISupportsArray_h__
#include "nsISupportsArray.h"
#endif

#ifndef __gen_nsrootidl_h__
#include "nsrootidl.h"
#endif

#ifndef __gen_nsIMsgIdentity_h__
#include "nsIMsgIdentity.h"
#endif

#ifndef __gen_nsIMsgCompFields_h__
#include "nsIMsgCompFields.h"
#endif

#ifndef __gen_nsIMsgSendListener_h__
#include "nsIMsgSendListener.h"
#endif

#ifndef __gen_nsIMsgSendLaterListener_h__
#include "nsIMsgSendLaterListener.h"
#endif

#ifndef __gen_nsIStreamListener_h__
#include "nsIStreamListener.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgWindow; /* forward declaration */

class nsIMsgFolder; /* forward declaration */


/* starting interface:    nsIMsgSendLater */
#define NS_IMSGSENDLATER_IID_STR "e15c83e8-1cf4-11d3-8ef0-00a024a7d144"

#define NS_IMSGSENDLATER_IID \
  {0xe15c83e8, 0x1cf4, 0x11d3, \
    { 0x8e, 0xf0, 0x00, 0xa0, 0x24, 0xa7, 0xd1, 0x44 }}

class NS_NO_VTABLE nsIMsgSendLater : public nsIStreamListener {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGSENDLATER_IID)

  /* void SendUnsentMessages (in nsIMsgIdentity identity); */
  NS_IMETHOD SendUnsentMessages(nsIMsgIdentity *identity) = 0;

  /* attribute nsIMsgWindow msgWindow; */
  NS_IMETHOD GetMsgWindow(nsIMsgWindow * *aMsgWindow) = 0;
  NS_IMETHOD SetMsgWindow(nsIMsgWindow * aMsgWindow) = 0;

  /* void RemoveListener (in nsIMsgSendLaterListener aListener); */
  NS_IMETHOD RemoveListener(nsIMsgSendLaterListener *aListener) = 0;

  /* void AddListener (in nsIMsgSendLaterListener aListener); */
  NS_IMETHOD AddListener(nsIMsgSendLaterListener *aListener) = 0;

  /* nsIMsgFolder getUnsentMessagesFolder (in nsIMsgIdentity userIdentity); */
  NS_IMETHOD GetUnsentMessagesFolder(nsIMsgIdentity *userIdentity, nsIMsgFolder **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSENDLATER \
  NS_IMETHOD SendUnsentMessages(nsIMsgIdentity *identity); \
  NS_IMETHOD GetMsgWindow(nsIMsgWindow * *aMsgWindow); \
  NS_IMETHOD SetMsgWindow(nsIMsgWindow * aMsgWindow); \
  NS_IMETHOD RemoveListener(nsIMsgSendLaterListener *aListener); \
  NS_IMETHOD AddListener(nsIMsgSendLaterListener *aListener); \
  NS_IMETHOD GetUnsentMessagesFolder(nsIMsgIdentity *userIdentity, nsIMsgFolder **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSENDLATER(_to) \
  NS_IMETHOD SendUnsentMessages(nsIMsgIdentity *identity) { return _to SendUnsentMessages(identity); } \
  NS_IMETHOD GetMsgWindow(nsIMsgWindow * *aMsgWindow) { return _to GetMsgWindow(aMsgWindow); } \
  NS_IMETHOD SetMsgWindow(nsIMsgWindow * aMsgWindow) { return _to SetMsgWindow(aMsgWindow); } \
  NS_IMETHOD RemoveListener(nsIMsgSendLaterListener *aListener) { return _to RemoveListener(aListener); } \
  NS_IMETHOD AddListener(nsIMsgSendLaterListener *aListener) { return _to AddListener(aListener); } \
  NS_IMETHOD GetUnsentMessagesFolder(nsIMsgIdentity *userIdentity, nsIMsgFolder **_retval) { return _to GetUnsentMessagesFolder(userIdentity, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSENDLATER(_to) \
  NS_IMETHOD SendUnsentMessages(nsIMsgIdentity *identity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SendUnsentMessages(identity); } \
  NS_IMETHOD GetMsgWindow(nsIMsgWindow * *aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMsgWindow(aMsgWindow); } \
  NS_IMETHOD SetMsgWindow(nsIMsgWindow * aMsgWindow) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMsgWindow(aMsgWindow); } \
  NS_IMETHOD RemoveListener(nsIMsgSendLaterListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveListener(aListener); } \
  NS_IMETHOD AddListener(nsIMsgSendLaterListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddListener(aListener); } \
  NS_IMETHOD GetUnsentMessagesFolder(nsIMsgIdentity *userIdentity, nsIMsgFolder **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUnsentMessagesFolder(userIdentity, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSendLater : public nsIMsgSendLater
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSENDLATER

  nsMsgSendLater();

private:
  ~nsMsgSendLater();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSendLater, nsIMsgSendLater)

nsMsgSendLater::nsMsgSendLater()
{
  /* member initializers and constructor code */
}

nsMsgSendLater::~nsMsgSendLater()
{
  /* destructor code */
}

/* void SendUnsentMessages (in nsIMsgIdentity identity); */
NS_IMETHODIMP nsMsgSendLater::SendUnsentMessages(nsIMsgIdentity *identity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgWindow msgWindow; */
NS_IMETHODIMP nsMsgSendLater::GetMsgWindow(nsIMsgWindow * *aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSendLater::SetMsgWindow(nsIMsgWindow * aMsgWindow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void RemoveListener (in nsIMsgSendLaterListener aListener); */
NS_IMETHODIMP nsMsgSendLater::RemoveListener(nsIMsgSendLaterListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void AddListener (in nsIMsgSendLaterListener aListener); */
NS_IMETHODIMP nsMsgSendLater::AddListener(nsIMsgSendLaterListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIMsgFolder getUnsentMessagesFolder (in nsIMsgIdentity userIdentity); */
NS_IMETHODIMP nsMsgSendLater::GetUnsentMessagesFolder(nsIMsgIdentity *userIdentity, nsIMsgFolder **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSendLater_h__ */
